(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    291398,       7006]
NotebookOptionsPosition[    271906,       6776]
NotebookOutlinePosition[    272246,       6791]
CellTagsIndexPosition[    272203,       6788]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
This Notebook contains the proofs of all the results in the paper
\"The Circumconics Among Us\" by Stanley Rabinowitz,
published in the International Journal of Computer Discovered Mathematics 
(http : // www.journal - 1. eu/) on May 2022.
 
This Notebook is Copyright \[Copyright] March 2021 by Stanley Rabinowitz \
(stan.rabinowitz@comcast.net) and is published with open access. This \
Notebook is distributed under the terms of the Creative Commons Attribution \
License which permits any use, distribution, and reproduction in any medium, \
provided the original author and the source are credited.\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.823362867312365*^9, 3.823362892123764*^9}, {
  3.823362940554699*^9, 3.823363012293025*^9}, {3.823423241988761*^9, 
  3.8234232521964083`*^9}, {3.848655919648938*^9, 3.8486559295098267`*^9}, {
  3.860780167178149*^9, 
  3.8607801820678587`*^9}},ExpressionUUID->"6e334438-a89a-48db-835f-\
405d667141bd"],

Cell[CellGroupData[{

Cell["Barycentric Coordinates for first 20 Kimberling Centers", "Chapter",
 Evaluatable->False,
 CellChangeTimes->{{3.848655957255249*^9, 3.848655989037887*^9}, 
   3.848656127231782*^9},ExpressionUUID->"8c6d2d97-d697-48c7-a27d-\
981caef5698c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ETC1", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"X1", ",", 
        RowBox[{"{", 
         RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"X2", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"X3", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"]}], ")"}]}], ",", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], "+", 
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"]}], ")"}]}], ",", 
          RowBox[{
           SuperscriptBox["c", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], "-", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"X4", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], "+", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], "+", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"X5", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["c", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["c", "2"]}], "+", 
           SuperscriptBox["c", "4"]}], ",", 
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["c", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["c", "2"]}], "+", 
           SuperscriptBox["c", "4"]}], ",", 
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           SuperscriptBox["b", "4"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["c", "2"]}], "-", 
           RowBox[{
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["c", "2"]}]}]}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"X6", ",", 
        RowBox[{"{", 
         RowBox[{
          SuperscriptBox["a", "2"], ",", 
          SuperscriptBox["b", "2"], ",", 
          SuperscriptBox["c", "2"]}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"X7", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"X8", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"a", "-", "b", "-", "c"}], ",", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "b", "-", "c"}], ",", 
          RowBox[{
           RowBox[{"-", "a"}], "-", "b", "+", "c"}]}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"X9", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "-", "c"}], ")"}]}], ",", 
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}]}], ",", 
          RowBox[{"c", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"X10", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"b", "+", "c"}], ",", 
          RowBox[{"a", "+", "c"}], ",", 
          RowBox[{"a", "+", "b"}]}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"X11", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "-", "b"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}]}]}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"X12", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"b", "+", "c"}], ")"}], "2"]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", "c"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"X13", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["b", "2"], "-", 
               SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "2"], "+", 
              SuperscriptBox["c", "2"], "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ",", 
          RowBox[{
           SuperscriptBox["b", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["a", "2"]}], "+", 
               SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["c", "2"], "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["a", "2"], "-", 
               SuperscriptBox["b", "2"]}], ")"}], "2"]}], "+", 
           SuperscriptBox["c", "4"], "+", 
           RowBox[{
            SuperscriptBox["c", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["b", "2"], "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", "S"}]}], ")"}]}]}]}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"X14", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["b", "2"], "-", 
               SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "2"], "+", 
              SuperscriptBox["c", "2"], "-", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ",", 
          RowBox[{
           SuperscriptBox["b", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["a", "2"]}], "+", 
               SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox["b", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["c", "2"], "-", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["a", "2"], "-", 
               SuperscriptBox["b", "2"]}], ")"}], "2"]}], "+", 
           SuperscriptBox["c", "4"], "+", 
           RowBox[{
            SuperscriptBox["c", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["b", "2"], "-", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", "S"}]}], ")"}]}]}]}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"X15", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SqrtBox["3"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["a", "2"], "-", 
                SuperscriptBox["b", "2"], "-", 
                SuperscriptBox["c", "2"]}], ")"}]}], "-", 
             RowBox[{"2", " ", "S"}]}], ")"}]}], ",", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SqrtBox["3"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["b", "2"], "-", 
                SuperscriptBox["c", "2"], "-", 
                SuperscriptBox["a", "2"]}], ")"}]}], "-", 
             RowBox[{"2", " ", "S"}]}], ")"}]}], "\[InvisibleSpace]", ",", 
          RowBox[{
           SuperscriptBox["c", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SqrtBox["3"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["c", "2"], "-", 
                SuperscriptBox["a", "2"], "-", 
                SuperscriptBox["b", "2"]}], ")"}]}], "-", 
             RowBox[{"2", " ", "S"}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"X16", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SqrtBox["3"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["a", "2"], "-", 
                SuperscriptBox["b", "2"], "-", 
                SuperscriptBox["c", "2"]}], ")"}]}], "+", 
             RowBox[{"2", " ", "S"}]}], ")"}]}], ",", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SqrtBox["3"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["b", "2"], "-", 
                SuperscriptBox["c", "2"], "-", 
                SuperscriptBox["a", "2"]}], ")"}]}], "+", 
             RowBox[{"2", " ", "S"}]}], ")"}]}], "\[InvisibleSpace]", ",", 
          RowBox[{
           SuperscriptBox["c", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SqrtBox["3"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["c", "2"], "-", 
                SuperscriptBox["a", "2"], "-", 
                SuperscriptBox["b", "2"]}], ")"}]}], "+", 
             RowBox[{"2", " ", "S"}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"X17", ",", 
        FormBox[
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"], "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", "S"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["b", "2"], "+", 
              SuperscriptBox["c", "2"], "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", "S"}]}], ")"}]}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "+", 
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"], "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", "S"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "+", 
              SuperscriptBox["b", "2"], "+", 
              SuperscriptBox["c", "2"], "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", "S"}]}], ")"}]}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["b", "2"], "+", 
              SuperscriptBox["c", "2"], "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", "S"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "+", 
              SuperscriptBox["b", "2"], "+", 
              SuperscriptBox["c", "2"], "+", 
              RowBox[{"2", " ", 
               SqrtBox["3"], " ", "S"}]}], ")"}]}]}], "}"}],
         TraditionalForm]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"X18", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"], "-", 
             RowBox[{"2", " ", 
              SqrtBox["3"], "S"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "-", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], "+", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "-", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"], "-", 
             RowBox[{"2", " ", 
              SqrtBox["3"], "S"}]}], ")"}]}], "\[InvisibleSpace]", ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "-", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], "+", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "-", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}]}], "\[InvisibleSpace]", 
         "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"X19", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}]}], ",", 
          RowBox[{"b", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], "+", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}]}], ",", 
          RowBox[{"c", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], "+", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"X20", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["a", "4"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "-", 
           SuperscriptBox["b", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["c", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["c", "2"]}], "-", 
           SuperscriptBox["c", "4"]}], ",", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "4"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["b", "4"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["c", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["c", "2"]}], "-", 
           SuperscriptBox["c", "4"]}], ",", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "4"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["b", "2"]}], "-", 
           SuperscriptBox["b", "4"], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox["c", "2"]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["c", "2"]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["c", "4"]}]}]}], "}"}]}], "}"}]}], 
     "\[IndentingNewLine]", "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "\[LessEqual]", "20"}], ",", 
    RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", "i", "]"}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"ETC1", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "2"}], "]"}], "]"}], "/.", 
         RowBox[{"S", "\[Rule]", 
          RowBox[{"2", 
           RowBox[{"Sqrt", "[", 
            RowBox[{"s", 
             RowBox[{"(", 
              RowBox[{"s", "-", "a"}], ")"}], 
             RowBox[{"(", 
              RowBox[{"s", "-", "b"}], ")"}], 
             RowBox[{"(", 
              RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
        RowBox[{"s", "\[Rule]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}], "//", 
       "Simplify"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], "Input",\

 CellChangeTimes->{{3.848064001896173*^9, 3.8480640169935093`*^9}, 
   3.848082183803338*^9, {3.848656191034729*^9, 3.848656191671677*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"c0e20cae-c86d-4901-b9d8-dd966f7cb7f1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Chapter",
 Evaluatable->False,
 CellChangeTimes->{{3.848655957255249*^9, 3.848655989037887*^9}, {
  3.848656127231782*^9, 
  3.848656156450227*^9}},ExpressionUUID->"41107464-cf9b-470f-a1df-\
e90f63cc77b8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ptA", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ptB", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"0", ",", " ", "1", ",", " ", "0"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"ptC", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"0", ",", " ", "0", ",", " ", "1"}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ConicThroughFivePoints", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x1_", ",", "y1_", ",", "z1_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x2_", ",", "y2_", ",", "z2_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x3_", ",", "y3_", ",", "z3_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x4_", ",", "y4_", ",", "z4_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x5_", ",", "y5_", ",", "z5_"}], "}"}]}], "]"}], " ", ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Det", "[", 
     RowBox[{"(", GridBox[{
        {
         SuperscriptBox["x", "2"], 
         SuperscriptBox["y", "2"], 
         SuperscriptBox["z", "2"], 
         RowBox[{"y", " ", "z"}], 
         RowBox[{"z", " ", "x"}], 
         RowBox[{"x", " ", "y"}]},
        {
         SuperscriptBox["x1", "2"], 
         SuperscriptBox["y1", "2"], 
         SuperscriptBox["z1", "2"], 
         RowBox[{"y1", " ", "z1"}], 
         RowBox[{"z1", " ", "x1"}], 
         RowBox[{"x1", " ", "y1"}]},
        {
         SuperscriptBox["x2", "2"], 
         SuperscriptBox["y2", "2"], 
         SuperscriptBox["z2", "2"], 
         RowBox[{"y2", " ", "z2"}], 
         RowBox[{"z2", " ", "x2"}], 
         RowBox[{"x2", " ", "y2"}]},
        {
         SuperscriptBox["x3", "2"], 
         SuperscriptBox["y3", "2"], 
         SuperscriptBox["z3", "2"], 
         RowBox[{"y3", " ", "z3"}], 
         RowBox[{"z3", " ", "x3"}], 
         RowBox[{"x3", " ", "y3"}]},
        {
         SuperscriptBox["x4", "2"], 
         SuperscriptBox["y4", "2"], 
         SuperscriptBox["z4", "2"], 
         RowBox[{"y4", " ", "z4"}], 
         RowBox[{"z4", " ", "x4"}], 
         RowBox[{"x4", " ", "y4"}]},
        {
         SuperscriptBox["x5", "2"], 
         SuperscriptBox["y5", "2"], 
         SuperscriptBox["z5", "2"], 
         RowBox[{"y5", " ", "z5"}], 
         RowBox[{"z5", " ", "x5"}], 
         RowBox[{"x5", " ", "y5"}]}
       }], ")"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"isConicQ", "[", 
     RowBox[{
     "p1_", ",", "p2_", ",", "p3_", ",", "p4_", ",", "p5_", ",", "p6_"}], 
     "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x6", ",", "y6", ",", "z6", ",", "con", ",", "eq"}], "}"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x6", ",", "y6", ",", "z6"}], "}"}], "=", "p6"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"con", "=", 
        RowBox[{"ConicThroughFivePoints", "[", 
         RowBox[{"p1", ",", "p2", ",", "p3", ",", "p4", ",", "p5"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"eq", "=", 
        RowBox[{"con", "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"x", "\[Rule]", "x6"}], ",", 
           RowBox[{"y", "\[Rule]", "y6"}], ",", 
           RowBox[{"z", "\[Rule]", "z6"}]}], "}"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"neq", "=", 
        RowBox[{"eq", "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"a", "\[Rule]", "6"}], ",", 
           RowBox[{"b", "\[Rule]", "9"}], ",", 
           RowBox[{"c", "\[Rule]", "13"}]}], "}"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", 
        RowBox[{
         RowBox[{"Simplify", "[", "neq", "]"}], "\[Equal]", "0"}], "]"}], 
       ";"}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"area6913", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{"s", 
        RowBox[{"(", 
         RowBox[{"s", "-", "a"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"s", "-", "b"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"s", "-", "c"}], ")"}]}], "]"}], "/.", 
      RowBox[{"{", 
       RowBox[{"s", "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "6"}], ",", 
       RowBox[{"b", "\[Rule]", "9"}], ",", 
       RowBox[{"c", "\[Rule]", "13"}]}], "}"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"circumCircle", "=", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", "y", " ", "z"}], " ", "+", " ", 
     RowBox[{
      SuperscriptBox["b", 
       RowBox[{"2", " "}]], "z", " ", "x"}], " ", "+", " ", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", "x", " ", "y"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SteinerEllipse", "=", 
   RowBox[{
    RowBox[{"y", " ", "z"}], "+", 
    RowBox[{"z", " ", "x"}], "+", 
    RowBox[{"x", " ", "y"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"getNormalized6913", "[", "center_", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "numericCenter", ",", "bx", ",", "by", ",", "bz", ",", "normalized"}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"centerabc", "=", 
        RowBox[{"center", "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            SubscriptBox["S", "A"], "\[Rule]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"b", "^", "2"}], "+", 
               RowBox[{"c", "^", "2"}], "-", 
               RowBox[{"a", "^", "2"}]}], ")"}], "/", "2"}]}], ",", 
           RowBox[{
            SubscriptBox["S", "\[Omega]"], "\[Rule]", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"a", "^", "2"}], "+", 
               RowBox[{"b", "^", "2"}], "+", 
               RowBox[{"c", "^", "2"}]}], ")"}], "/", "2"}]}], ",", 
           RowBox[{"S", "\[Rule]", 
            RowBox[{"2", "area6913"}]}]}], "}"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"bx", ",", "by", ",", "bz"}], "}"}], "=", 
        RowBox[{"numericCenter", "=", 
         RowBox[{"centerabc", "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"a", "\[Rule]", "6"}], ",", 
            RowBox[{"b", "\[Rule]", "9"}], ",", 
            RowBox[{"c", "\[Rule]", "13"}]}], "}"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Total", "[", "numericCenter", "]"}], "\[Equal]", "0"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "center", " ", "is", " ", "on", " ", "line", " ", "at", " ", 
           "infinity"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"normalized", "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"1", "/", "bx"}], "+", 
              RowBox[{"1", "/", "by"}], "+", 
              RowBox[{"1", "/", "bz"}]}], ")"}], "bx"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Return", "[", 
           RowBox[{"N", "[", 
            RowBox[{"normalized", ",", "20"}], "]"}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"convert", " ", "to", " ", "trilinear", " ", "coordinates"}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"bx", ",", "by", ",", "bz"}], "}"}], "=", 
        RowBox[{"numericCenter", "/", 
         RowBox[{"{", 
          RowBox[{"6", ",", "9", ",", "13"}], "}"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"normalized", "=", 
        RowBox[{"(", 
         RowBox[{"2", "area6913", "*", 
          RowBox[{"bx", "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", "bx"}], "+", 
             RowBox[{"9", " ", "by"}], "+", 
             RowBox[{"13", " ", "bz"}]}], ")"}]}]}], ")"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Return", "[", 
        RowBox[{"N", "[", 
         RowBox[{"normalized", ",", "20"}], "]"}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"checkSymmetry", "[", "expr_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"expr2", ",", "q"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"expr2", "=", 
       RowBox[{"expr", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"b", "\[Rule]", "c"}], ",", 
          RowBox[{"c", "\[Rule]", "b"}]}], "}"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"q", "=", 
       RowBox[{"Simplify", "[", 
        RowBox[{"expr2", "/", "expr"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"q", "=!=", "1"}], "&&", " ", 
         RowBox[{"q", "=!=", 
          RowBox[{"-", "1"}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
         "Print", "[", "\"\<********* NOT b/c SYMMETRIC ********\>\"", "]"}], 
         ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8480635788427887`*^9, 3.8480635895309353`*^9}, {
  3.848251230348947*^9, 3.848251421861019*^9}, {3.8482514724771214`*^9, 
  3.8482515411170692`*^9}, {3.848258724756899*^9, 3.8482587301075068`*^9}, {
  3.848516889425885*^9, 3.848516897728187*^9}, {3.848518619927168*^9, 
  3.848518623669732*^9}, {3.848518683422716*^9, 3.8485186847652493`*^9}, {
  3.848518915463603*^9, 3.8485189175100117`*^9}, {3.848519104216136*^9, 
  3.848519152799162*^9}, {3.848656215862256*^9, 3.848656252863151*^9}, {
  3.84865700581919*^9, 3.848657016433899*^9}, {3.848657276692852*^9, 
  3.848657280683733*^9}, {3.848737590980174*^9, 3.8487376305780067`*^9}, {
  3.848738427021881*^9, 3.84873842804423*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"68c74ca1-8553-439a-9bb5-5bb82e6a9d4c"]
}, Closed]],

Cell[CellGroupData[{

Cell["Search for Circumconics", "Chapter",
 Evaluatable->False,
 CellChangeTimes->{{3.848655957255249*^9, 3.848655989037887*^9}, {
  3.848656127231782*^9, 3.848656156450227*^9}, {3.848656272943198*^9, 
  3.848656305158951*^9}},ExpressionUUID->"456ec704-8b01-48a2-80e0-\
3ef9c52904ff"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"maxIndex", "=", "20"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "\[LessEqual]", "maxIndex"}], ",", 
    RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pt1", "=", 
      RowBox[{"x", "[", "i", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"j", "=", 
        RowBox[{"i", "+", "1"}]}], ",", 
       RowBox[{"j", "\[LessEqual]", "maxIndex"}], ",", 
       RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"pt2", "=", 
         RowBox[{"x", "[", "j", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"k", "=", 
           RowBox[{"j", "+", "1"}]}], ",", 
          RowBox[{"k", "\[LessEqual]", "maxIndex"}], ",", 
          RowBox[{"k", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"pt3", "=", 
            RowBox[{"x", "[", "k", "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"isConicQ", "[", 
              RowBox[{
              "ptA", ",", "ptB", ",", "ptC", ",", "pt1", ",", "pt2", ",", 
               "pt3"}], "]"}], ",", "\[IndentingNewLine]", 
             RowBox[{"{", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Print", "[", 
                RowBox[{"\"\<Conic \>\"", ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "j", ",", "k"}], "}"}]}], "]"}], ";"}], 
              "\[IndentingNewLine]", "}"}]}], "\[IndentingNewLine]", "]"}], 
           ";"}]}], "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
      "]"}]}]}], "\[IndentingNewLine]", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.848064334765616*^9, 3.84806451620685*^9}, {
   3.8480648987758923`*^9, 3.848065042952277*^9}, {3.848065469476293*^9, 
   3.848065469818067*^9}, {3.848084259377915*^9, 3.848084263752393*^9}, {
   3.848084312585084*^9, 3.848084335577434*^9}, {3.848084366666729*^9, 
   3.848084422153473*^9}, {3.848084569914257*^9, 3.848084632010284*^9}, {
   3.8480846694759502`*^9, 3.848084670834222*^9}, {3.848084714774458*^9, 
   3.848084741868947*^9}, {3.848084779644758*^9, 3.84808480655651*^9}, 
   3.8480848407959003`*^9, {3.8480848792922564`*^9, 3.848084890090962*^9}, {
   3.848084954723097*^9, 3.848084975331464*^9}, {3.8480851403896303`*^9, 
   3.8480851448519363`*^9}, {3.848085228135099*^9, 3.8480852423244133`*^9}, {
   3.848085319476729*^9, 3.848085345555542*^9}, 3.84808583097468*^9, {
   3.848085910118572*^9, 3.848085929005226*^9}, {3.848086156936892*^9, 
   3.848086175469541*^9}, {3.848086296030353*^9, 3.848086330017523*^9}, {
   3.848086391590748*^9, 3.8480865126023607`*^9}, 3.84808659655278*^9, {
   3.8480866519446373`*^9, 3.848086654814932*^9}, 3.84808675314332*^9, {
   3.848087251767215*^9, 3.848087254602292*^9}, {3.848087304764618*^9, 
   3.8480873520520353`*^9}, {3.848087389757111*^9, 3.848087390563184*^9}, {
   3.848152280975479*^9, 3.8481523366062527`*^9}, {3.848152513294983*^9, 
   3.8481525250001087`*^9}, {3.848152820648014*^9, 3.848152864424305*^9}, {
   3.848152946962563*^9, 3.848152966160482*^9}, {3.848153116859118*^9, 
   3.848153119913142*^9}, {3.848153691652893*^9, 3.8481537307073107`*^9}, {
   3.848153770828464*^9, 3.848153800683352*^9}, {3.848153949622018*^9, 
   3.8481539499318542`*^9}, 3.848166119788701*^9, 3.848166164057152*^9, {
   3.84816748683937*^9, 3.8481674886696043`*^9}, {3.848172330323895*^9, 
   3.848172337366365*^9}, {3.8481754014067917`*^9, 3.848175422350148*^9}, {
   3.848175579350678*^9, 3.848175607846739*^9}, {3.84817568303586*^9, 
   3.848175735503193*^9}, {3.848175956869584*^9, 3.8481760451211367`*^9}, {
   3.848261446278922*^9, 3.8482614839805717`*^9}, {3.84851699434545*^9, 
   3.848517118267831*^9}, {3.8485178194999228`*^9, 3.848517914067196*^9}, {
   3.848517969492547*^9, 3.848518091828576*^9}, {3.8485181259729767`*^9, 
   3.848518154259961*^9}, {3.848518199623272*^9, 3.8485182002760363`*^9}, {
   3.848518233350657*^9, 3.8485182919565573`*^9}, {3.848518329358159*^9, 
   3.848518416517992*^9}, {3.848518449846456*^9, 3.848518461636894*^9}, {
   3.848518952078302*^9, 3.848518965495525*^9}, {3.8485192720216627`*^9, 
   3.848519292103656*^9}, {3.8485193333603563`*^9, 3.848519340104123*^9}, {
   3.848519404960734*^9, 3.8485194090245934`*^9}, {3.8485194609131002`*^9, 
   3.848519487873209*^9}, {3.8485196117331057`*^9, 3.848519666793158*^9}, {
   3.8485207910242023`*^9, 3.848520803380639*^9}, 3.848520857088915*^9, {
   3.848521649616926*^9, 3.848521654287714*^9}, {3.848521807664765*^9, 
   3.8485218199115953`*^9}, 3.8485619763462343`*^9},
 CellLabel->"In[13]:=",ExpressionUUID->"ae12587e-cdb4-4d5e-b902-301e30965b29"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4", ",", "7"}], "}"}]}],
  SequenceForm["Conic ", {1, 4, 7}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780191479286*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"6d5f6787-16bd-4bd2-abaf-f46afdb219e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4", ",", "8"}], "}"}]}],
  SequenceForm["Conic ", {1, 4, 8}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.8607801914798317`*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"0207fe42-a55d-446d-89df-c68973ee2302"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4", ",", "9"}], "}"}]}],
  SequenceForm["Conic ", {1, 4, 9}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.8607801914821167`*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"98ee7c3f-73d7-40c3-a7b1-39a527e52736"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "7", ",", "8"}], "}"}]}],
  SequenceForm["Conic ", {1, 7, 8}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780192038349*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"2895178c-b10f-4756-9c21-ed857d812a7c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "7", ",", "9"}], "}"}]}],
  SequenceForm["Conic ", {1, 7, 9}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780192042953*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"4a610b8a-1631-4050-9a89-01d9e1cc4aec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "8", ",", "9"}], "}"}]}],
  SequenceForm["Conic ", {1, 8, 9}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.8607801922304993`*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"0844de95-fca7-46d2-917a-529ae67e86dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "10", ",", "19"}], "}"}]}],
  SequenceForm["Conic ", {1, 10, 19}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780192718163*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"bce2154a-1327-4737-9634-bb93ae40efb4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "4", ",", "10"}], "}"}]}],
  SequenceForm["Conic ", {2, 4, 10}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.86078019515355*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"396fd63c-5959-4704-b5c2-8bf815e16a85"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "4", ",", "13"}], "}"}]}],
  SequenceForm["Conic ", {2, 4, 13}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.8607801952243156`*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"a0f6a96e-0ab9-4037-a1db-96bc8f464f10"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "4", ",", "14"}], "}"}]}],
  SequenceForm["Conic ", {2, 4, 14}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780195303982*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"5c1ae25d-edd9-467b-8c53-fb8d052c8303"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "4", ",", "17"}], "}"}]}],
  SequenceForm["Conic ", {2, 4, 17}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780195305126*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"0a140c48-225d-487c-9869-6ef5f653136a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "4", ",", "18"}], "}"}]}],
  SequenceForm["Conic ", {2, 4, 18}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780195391844*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"c3283fa0-804b-4b79-97bf-f3218ba49721"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "10", ",", "13"}], "}"}]}],
  SequenceForm["Conic ", {2, 10, 13}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.8607801960964746`*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"8b8563e4-a80a-4035-9510-858d2d012394"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "10", ",", "14"}], "}"}]}],
  SequenceForm["Conic ", {2, 10, 14}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.8607801961796417`*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"9d035a53-f51b-4dcd-85df-48437e966255"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "10", ",", "17"}], "}"}]}],
  SequenceForm["Conic ", {2, 10, 17}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.8607801961806087`*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"035dbdd3-5b19-4819-9af3-36aaf21d55e5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "10", ",", "18"}], "}"}]}],
  SequenceForm["Conic ", {2, 10, 18}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780196181464*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"e81d7adb-e11c-4f26-bacd-052095cd8b96"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "13", ",", "14"}], "}"}]}],
  SequenceForm["Conic ", {2, 13, 14}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780196583105*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"5bb16ec0-e3f9-46ce-8869-0be8234808ff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "13", ",", "17"}], "}"}]}],
  SequenceForm["Conic ", {2, 13, 17}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780196717054*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"13ca8fbf-053b-4dfd-9ae8-237d138d7f36"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "13", ",", "18"}], "}"}]}],
  SequenceForm["Conic ", {2, 13, 18}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780196814934*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"857590c7-104a-4aa6-a90a-c29551bccc79"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "14", ",", "17"}], "}"}]}],
  SequenceForm["Conic ", {2, 14, 17}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780197024167*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"f49c7ebf-fdb1-4964-9aad-b8c83c10c2dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "14", ",", "18"}], "}"}]}],
  SequenceForm["Conic ", {2, 14, 18}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780197129416*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"989e8f50-02a4-46d0-b8c4-85ea97ec7da1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "15", ",", "16"}], "}"}]}],
  SequenceForm["Conic ", {2, 15, 16}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780197256229*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"193a33df-c67c-4af3-9a24-7b07ef86d41d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "17", ",", "18"}], "}"}]}],
  SequenceForm["Conic ", {2, 17, 18}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780197452696*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"f667312e-e734-4b72-b727-f034c05f88ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4", ",", "6"}], "}"}]}],
  SequenceForm["Conic ", {3, 4, 6}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.86078019773818*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"dedc5773-ef6b-4a83-b376-136f9cdb3ab7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "15", ",", "17"}], "}"}]}],
  SequenceForm["Conic ", {3, 15, 17}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780200931819*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"57cc897a-d8dd-4549-9622-62859e840957"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "16", ",", "18"}], "}"}]}],
  SequenceForm["Conic ", {3, 16, 18}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780201230421*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"45c16e98-9dcd-4af5-bc1f-7e05502dcd15"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "7", ",", "8"}], "}"}]}],
  SequenceForm["Conic ", {4, 7, 8}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780202601446*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"55844180-c51a-4982-bd13-27ea958ed6d3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "7", ",", "9"}], "}"}]}],
  SequenceForm["Conic ", {4, 7, 9}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780202633312*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"d5bcabb6-afc4-4131-833e-10fca0550ef9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "8", ",", "9"}], "}"}]}],
  SequenceForm["Conic ", {4, 8, 9}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780202885108*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"13b07777-5d97-4c8d-8daf-970378acbc74"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "10", ",", "13"}], "}"}]}],
  SequenceForm["Conic ", {4, 10, 13}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780203436941*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"f29d71c6-0864-40b3-ba47-bc2bafa67e5f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "10", ",", "14"}], "}"}]}],
  SequenceForm["Conic ", {4, 10, 14}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.8607802034872847`*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"be0ee609-74ad-4f80-b59a-eeaf4e11b2e9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "10", ",", "17"}], "}"}]}],
  SequenceForm["Conic ", {4, 10, 17}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780203544458*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"72e562c9-e881-48fe-ade4-d44ab181b1e8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "10", ",", "18"}], "}"}]}],
  SequenceForm["Conic ", {4, 10, 18}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.86078020358563*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"1932bfb8-0d13-4cf0-bad8-1b45249b7ed1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "13", ",", "14"}], "}"}]}],
  SequenceForm["Conic ", {4, 13, 14}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780204244836*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"6ad10d39-fd14-4a03-aa24-a2f778a33cca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "13", ",", "17"}], "}"}]}],
  SequenceForm["Conic ", {4, 13, 17}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780204543146*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"6d1109e1-017f-4e59-bf5c-c6ed174490a0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "13", ",", "18"}], "}"}]}],
  SequenceForm["Conic ", {4, 13, 18}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780204672059*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"16073084-f8d4-44b5-b07e-dd4a146ff74e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "14", ",", "17"}], "}"}]}],
  SequenceForm["Conic ", {4, 14, 17}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.8607802051772346`*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"0fe8625d-d02d-4c8f-b776-57a0c1446997"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "14", ",", "18"}], "}"}]}],
  SequenceForm["Conic ", {4, 14, 18}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780205303134*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"7fd550eb-6b3f-41c2-b0bb-1d37f82fd2eb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "17", ",", "18"}], "}"}]}],
  SequenceForm["Conic ", {4, 17, 18}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780206621797*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"459a14c2-567f-401a-bd07-d125a8fa74d6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"6", ",", "9", ",", "19"}], "}"}]}],
  SequenceForm["Conic ", {6, 9, 19}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780213046324*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"2de74566-ca4b-42d5-888e-ee6fb90295c7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"6", ",", "13", ",", "16"}], "}"}]}],
  SequenceForm["Conic ", {6, 13, 16}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.8607802137716923`*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"894de550-5d83-4939-86b8-28d8683b0a0a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"6", ",", "14", ",", "15"}], "}"}]}],
  SequenceForm["Conic ", {6, 14, 15}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.8607802140459547`*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"1686bc5e-6378-429f-9f7b-a6ab7b6b7fcd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"7", ",", "8", ",", "9"}], "}"}]}],
  SequenceForm["Conic ", {7, 8, 9}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.8607802150557737`*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"be0fba6a-fed4-425e-a7c5-b73e2f23d4b9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"10", ",", "13", ",", "14"}], "}"}]}],
  SequenceForm["Conic ", {10, 13, 14}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780228167799*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"eb520553-6373-4b9b-b366-60d398642490"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"10", ",", "13", ",", "17"}], "}"}]}],
  SequenceForm["Conic ", {10, 13, 17}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780228497211*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"3fa1a77c-0bb8-4678-9821-17afcba49b8b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"10", ",", "13", ",", "18"}], "}"}]}],
  SequenceForm["Conic ", {10, 13, 18}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.8607802286099577`*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"2280fbd6-5585-4196-a052-f9018876a663"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"10", ",", "14", ",", "17"}], "}"}]}],
  SequenceForm["Conic ", {10, 14, 17}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780229111556*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"01a3ea61-0238-4f2e-a71e-aea955630ec7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"10", ",", "14", ",", "18"}], "}"}]}],
  SequenceForm["Conic ", {10, 14, 18}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780229227109*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"34a5404a-2307-44d6-8c52-897cf88bd668"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"10", ",", "17", ",", "18"}], "}"}]}],
  SequenceForm["Conic ", {10, 17, 18}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780230088024*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"d8f90dc3-299a-435d-ae9c-8cf1e20cebe9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"13", ",", "14", ",", "17"}], "}"}]}],
  SequenceForm["Conic ", {13, 14, 17}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780244188429*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"63a91843-7c64-4ebf-b4e0-06942a50b08c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"13", ",", "14", ",", "18"}], "}"}]}],
  SequenceForm["Conic ", {13, 14, 18}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780244382839*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"6f6dae61-3397-499c-972f-337077bbe76f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"13", ",", "17", ",", "18"}], "}"}]}],
  SequenceForm["Conic ", {13, 17, 18}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.8607802470945253`*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"9d9d15e4-0f9a-486e-b243-2c58fc62526e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Conic \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"14", ",", "17", ",", "18"}], "}"}]}],
  SequenceForm["Conic ", {14, 17, 18}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.848176057881516*^9, {3.848261447772807*^9, 3.848261470321969*^9}, 
   3.8482615017304068`*^9, {3.848517092692812*^9, 3.848517119508318*^9}, 
   3.848517859113802*^9, 3.848517915394814*^9, 3.848518016501151*^9, 
   3.848518093399823*^9, 3.848518155312042*^9, 3.848518201478044*^9, 
   3.848518247109159*^9, 3.848518293242796*^9, {3.848518380711905*^9, 
   3.848518417363702*^9}, 3.848518462911583*^9, 3.8485187042639313`*^9, 
   3.848518967470355*^9, 3.8485191685294123`*^9, 3.848519489502483*^9, 
   3.848519636227805*^9, 3.848519669947364*^9, 3.8485208077355537`*^9, 
   3.848520858948818*^9, 3.848521826249569*^9, 3.848562009838583*^9, 
   3.848566622332912*^9, 3.848583284139594*^9, 3.848656758103344*^9, 
   3.8487370583265676`*^9, 3.860780251317586*^9},
 CellLabel->
  "During evaluation of \
In[13]:=",ExpressionUUID->"90707040-27a4-46a6-9af5-f4f70107ff0d"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Get points associated with the Circumconics", "Chapter",
 Evaluatable->False,
 CellChangeTimes->{{3.848655957255249*^9, 3.848655989037887*^9}, {
  3.848656127231782*^9, 3.848656156450227*^9}, {3.848656272943198*^9, 
  3.848656333638954*^9}},ExpressionUUID->"1e6baa0c-c21e-4dfc-874b-\
bd5d4473ce88"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "consolidate", " ", "the", " ", "list", " ", "to", " ", "unique", " ", 
    "conics"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"circumConicList", "=", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"2", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"2", ",", "15"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"3", ",", "15"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"3", ",", "16"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"6", ",", "9"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"6", ",", "13"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"6", ",", "14"}], "}"}]}], "\[IndentingNewLine]", "}"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Get", " ", "info", " ", "about", " ", "each", " ", "conic"}], 
    " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"simpRules", "=", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "4"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "-", 
          SuperscriptBox["b", "4"], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          SuperscriptBox["c", "4"]}], "]"}], "\[Rule]", 
        RowBox[{"2", "S"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"]}], "\[Rule]", 
        RowBox[{
         RowBox[{"-", "2"}], 
         SubscriptBox["S", "A"]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"], "-", 
         RowBox[{"a", "^", "2"}]}], "\[Rule]", 
        RowBox[{"2", 
         SubscriptBox["S", "A"]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"b", "-", "c"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}], "\[Rule]", 
        RowBox[{
         RowBox[{"b", "^", "2"}], "-", 
         RowBox[{"c", "^", "2"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"b", "-", "c"}], ")"}], "^", "2"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], "^", "2"}]}], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"b", "^", "2"}], "-", 
           RowBox[{"c", "^", "2"}]}], ")"}], "^", "2"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "^", "2"}], "+", 
         RowBox[{"b", "^", "2"}], "+", 
         RowBox[{"c", "^", "2"}]}], "\[Rule]", 
        RowBox[{"2", 
         SubscriptBox["S", "\[Omega]"]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"b", " ", "c"}], "-", 
           RowBox[{"2", " ", 
            SubscriptBox["S", "A"]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"b", " ", "c"}], "+", 
           RowBox[{"2", " ", 
            SubscriptBox["S", "A"]}]}], ")"}]}], "\[Rule]", 
        RowBox[{
         RowBox[{
          RowBox[{"b", "^", "2"}], 
          RowBox[{"c", "^", "2"}]}], "-", 
         RowBox[{"4", 
          RowBox[{
           SubscriptBox["S", "A"], "^", "2"}]}]}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"b", " ", "c"}], "-", 
            RowBox[{"2", " ", 
             SubscriptBox["S", "A"]}]}], ")"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"b", " ", "c"}], "+", 
            RowBox[{"2", " ", 
             SubscriptBox["S", "A"]}]}], ")"}], "2"]}], "\[Rule]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"b", "^", "2"}], 
            RowBox[{"c", "^", "2"}]}], "-", 
           RowBox[{"4", 
            RowBox[{
             SubscriptBox["S", "A"], "^", "2"}]}]}], ")"}], "^", "2"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "\[Rule]", 
        RowBox[{
         RowBox[{
          RowBox[{"a", "^", "2"}], 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"b", "^", "2"}], 
          RowBox[{"c", "^", "2"}]}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], "-", 
         RowBox[{"b", " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], "+", 
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"b", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "\[Rule]", 
        RowBox[{
         RowBox[{"a", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", "^", "2"}], "+", 
            RowBox[{"b", "^", "2"}], "+", 
            RowBox[{"c", "^", "2"}]}], ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", 
             RowBox[{"a", "^", "2"}]}], "+", 
            RowBox[{"b", " ", "c"}]}], ")"}]}], "+", 
         RowBox[{"a", " ", "b", " ", "c"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", 
          SuperscriptBox["a", "2"], "S"}]}], "\[Rule]", 
        RowBox[{
         RowBox[{
          RowBox[{"a", "^", "2"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", "^", "2"}], "+", 
            RowBox[{"b", "^", "2"}], "+", 
            RowBox[{"c", "^", "2"}]}], ")"}]}], "-", 
         RowBox[{"2", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"b", "^", "2"}], "-", 
             RowBox[{"c", "^", "2"}]}], ")"}], "^", "2"}]}], "+", 
         RowBox[{"2", 
          SuperscriptBox["a", "2"], " ", 
          SqrtBox["3"], " ", "S"}]}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["b", "4"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"]}], "-", 
         SuperscriptBox["c", "4"]}], "\[Rule]", 
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], "2"]}]}]}], 
      "\[IndentingNewLine]", 
      RowBox[{"(*", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x_", "-", "y_"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"x_", "+", "y_"}], ")"}]}], "\[Rule]", 
        RowBox[{
         RowBox[{"x", "^", "2"}], "-", 
         RowBox[{"y", "^", "2"}]}]}], "\[IndentingNewLine]", "*)"}], 
      "\[IndentingNewLine]", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"simpOrFactor", "[", "expr_", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "fact", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"fact", "=", 
         RowBox[{"Factor", "[", "expr", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Head", "[", "fact", "]"}], "===", "Times"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Return", "[", "fact", "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Return", "[", 
           RowBox[{"Simplify", "[", "expr", "]"}], "]"}]}], 
         "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", 
      "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"simp", "[", "expr_", "]"}], ":=", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "simpl", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"simpl", "=", 
         RowBox[{
          RowBox[{"Factor", "[", "expr", "]"}], "//.", "simpRules"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"simpl", "=", 
         RowBox[{"PowerExpand", "[", "simpl", "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Head", "[", "simpl", "]"}], "===", "Times"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"simpl", "=", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Collect", "[", 
               RowBox[{"#", ",", 
                RowBox[{"{", 
                 RowBox[{"S", ",", 
                  RowBox[{"Sqrt", "[", "3", "]"}]}], "}"}], ",", 
                "simpOrFactor"}], "]"}], "&"}], ",", "simpl"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"simpl", "=", 
           RowBox[{"Collect", "[", 
            RowBox[{"simpl", ",", 
             RowBox[{"{", 
              RowBox[{"S", ",", 
               RowBox[{"Sqrt", "[", "3", "]"}]}], "}"}], ",", 
             "simpOrFactor"}], "]"}]}]}], "\[IndentingNewLine]", "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"simpl", "=", 
         RowBox[{"simpl", "//.", "simpRules"}]}], ";", "\[IndentingNewLine]", 
        
        RowBox[{"simpl", "=", 
         RowBox[{"Simplify", "[", "simpl", "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"simpl", "=", 
         RowBox[{"simpl", "//.", "simpRules"}]}], ";", "\[IndentingNewLine]", 
        
        RowBox[{"Return", "[", "simpl", "]"}], ";"}]}], "\[IndentingNewLine]",
       "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Get", " ", "the", " ", "info"}], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"n", "=", "1"}], ",", 
      RowBox[{"n", "\[LessEqual]", "10"}], ",", 
      RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"pt1", ",", "pt2"}], "}"}], "=", 
        RowBox[{"circumConicList", "[", 
         RowBox[{"[", "n", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Get", " ", "its", " ", "equation"}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"conic", "=", 
        RowBox[{"ConicThroughFivePoints", "[", 
         RowBox[{"ptA", ",", "ptB", ",", "ptC", ",", 
          RowBox[{"x", "[", "pt1", "]"}], ",", 
          RowBox[{"x", "[", "pt2", "]"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"factoredConic", "=", 
        RowBox[{"FactorList", "[", "conic", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"freeCon", "=", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"FreeQ", "[", 
              RowBox[{
               RowBox[{"#", "[", 
                RowBox[{"[", "1", "]"}], "]"}], ",", "x"}], "]"}], ",", 
             "Nothing", ",", "#"}], "]"}], "&"}], ",", "factoredConic"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"recombine", " ", "factors"}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"freeConic", "=", 
        RowBox[{"Times", "@@", 
         RowBox[{"Power", "@@@", "freeCon"}]}]}], ";", "\[IndentingNewLine]", 
       
       RowBox[{"yzcoef", "=", 
        RowBox[{"Coefficient", "[", 
         RowBox[{"freeConic", ",", 
          RowBox[{"y", " ", "z"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"simpl", "=", 
        RowBox[{"simp", "[", "yzcoef", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"eq", "[", "n", "]"}], "=", "simpl"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{
          RowBox[{"\"\<Conic \>\"", "<>", 
           RowBox[{"ToString", "[", "pt1", "]"}], "<>", "\"\<-\>\"", "<>", 
           RowBox[{"ToString", "[", "pt2", "]"}], "<>", "\"\<:\>\""}], ",", 
          "18", ",", "Bold", ",", "Red"}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<      Equation: \>\"", ",", "simpl"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Find", " ", "the", " ", "center"}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"p", "=", 
        RowBox[{"Coefficient", "[", 
         RowBox[{"freeConic", ",", 
          RowBox[{"y", " ", "z"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"q", "=", 
        RowBox[{"Coefficient", "[", 
         RowBox[{"freeConic", ",", 
          RowBox[{"z", " ", "x"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"r", "=", 
        RowBox[{"Coefficient", "[", 
         RowBox[{"freeConic", ",", 
          RowBox[{"x", " ", "y"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"centerx", "=", 
        RowBox[{"simp", "[", 
         RowBox[{"p", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "p"}], "+", "q", "+", "r"}], ")"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"centery", "=", 
        RowBox[{"simp", "[", 
         RowBox[{"q", 
          RowBox[{"(", 
           RowBox[{"p", "-", "q", "+", "r"}], ")"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"centerz", "=", 
        RowBox[{"simp", "[", 
         RowBox[{"r", 
          RowBox[{"(", 
           RowBox[{"p", "+", "q", "-", "r"}], ")"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<      Center: \>\"", ",", "centerx", ",", "\"\<::\>\""}],
         "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<TeX=\>\"", ",", 
         RowBox[{"TeXForm", "[", "centerx", "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"checkSymmetry", "[", "centerx", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"center6913", "=", 
        RowBox[{"getNormalized6913", "[", 
         RowBox[{"{", 
          RowBox[{"centerx", ",", "centery", ",", "centerz"}], "}"}], "]"}]}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<      center 6-9-13: \>\"", ",", "center6913"}], "]"}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"Find", " ", "the", " ", "perspector"}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<      Persp: \>\"", ",", 
         RowBox[{"simp", "[", "p", "]"}], ",", "\"\<::\>\""}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"persp6913", "=", 
        RowBox[{"getNormalized6913", "[", 
         RowBox[{"{", 
          RowBox[{"p", ",", "q", ",", "r"}], "}"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<      persp  6-9-13: \>\"", ",", "persp6913"}], "]"}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"checkSymmetry", "[", "p", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Find", " ", "the", " ", "4", "th", " ", "point", " ", "of", " ", 
         "intersection", " ", "with", " ", "circumcircle"}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"fourthx", "=", 
        RowBox[{"1", "/", 
         RowBox[{"simp", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"b", "^", "2"}], "r"}], "-", 
           RowBox[{
            RowBox[{"c", "^", "2"}], "q"}]}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"fourthy", "=", 
        RowBox[{"1", "/", 
         RowBox[{"simp", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"c", "^", "2"}], "p"}], "-", 
           RowBox[{
            RowBox[{"a", "^", "2"}], "r"}]}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"fourthz", "=", 
        RowBox[{"1", "/", 
         RowBox[{"simp", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"a", "^", "2"}], "q"}], "-", 
           RowBox[{
            RowBox[{"b", "^", "2"}], "p"}]}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<      4th: \>\"", ",", "fourthx", ",", "\"\<::\>\""}], 
        "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<TeX=\>\"", ",", 
         RowBox[{"TeXForm", "[", 
          RowBox[{"simp", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"b", "^", "2"}], "r"}], "-", 
            RowBox[{
             RowBox[{"c", "^", "2"}], "q"}]}], "]"}], "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"fourth6913", "=", 
        RowBox[{"getNormalized6913", "[", 
         RowBox[{"{", 
          RowBox[{"fourthx", ",", "fourthy", ",", "fourthz"}], "}"}], "]"}]}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<      4th 6-9-13: \>\"", ",", "fourth6913"}], "]"}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"checkSymmetry", "[", "fourthx", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Find", " ", "the", " ", "4", "th", " ", "point", " ", "of", " ", 
         "intersection", " ", "with", " ", "Steiner", " ", "ellipse"}], " ", 
        "*)"}], "\[IndentingNewLine]", 
       RowBox[{"steinerx", "=", 
        RowBox[{"1", "/", 
         RowBox[{"simp", "[", 
          RowBox[{"r", "-", "q"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"steinery", "=", 
        RowBox[{"1", "/", 
         RowBox[{"simp", "[", 
          RowBox[{"p", "-", "r"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"steinerz", "=", 
        RowBox[{"1", "/", 
         RowBox[{"simp", "[", 
          RowBox[{"q", "-", "p"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<      Steiner 4th: \>\"", ",", "steinerx", ",", "\"\<::\>\""}], 
        "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<TeX=\>\"", ",", 
         RowBox[{"TeXForm", "[", 
          RowBox[{"simp", "[", 
           RowBox[{"r", "-", "q"}], "]"}], "]"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"checkSymmetry", "[", "steinerx", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"steinerfourth6913", "=", 
        RowBox[{"getNormalized6913", "[", 
         RowBox[{"{", 
          RowBox[{"steinerx", ",", "steinery", ",", "steinerz"}], "}"}], 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<      Steiner 4th 6-9-13: \>\"", ",", "steinerfourth6913"}], 
        "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{
  3.848562132914611*^9, {3.848656347026276*^9, 3.848656370769561*^9}, {
   3.848657144066751*^9, 3.848657157812057*^9}, {3.848657323275771*^9, 
   3.848657344109243*^9}, {3.848658740914572*^9, 3.848658748545721*^9}, {
   3.848736878481389*^9, 3.848736948656116*^9}, {3.848736981658124*^9, 
   3.8487369841060743`*^9}, {3.8487370166341667`*^9, 
   3.8487370444491053`*^9}, {3.848737259971232*^9, 3.848737293003512*^9}, {
   3.8487377071947117`*^9, 3.848737726851658*^9}, {3.848737910299068*^9, 
   3.848737940908609*^9}, {3.848738023475129*^9, 3.8487380757964163`*^9}, {
   3.848738108347534*^9, 3.848738124997428*^9}, {3.8487384542520103`*^9, 
   3.848738476989772*^9}, {3.848738534892295*^9, 3.848738538349884*^9}, {
   3.8487387698736362`*^9, 3.848738884320912*^9}, 3.848739021695422*^9, {
   3.848739203079974*^9, 3.848739246481596*^9}, 3.8487395268246183`*^9, {
   3.848740381548254*^9, 3.84874039417343*^9}, {3.848740436942474*^9, 
   3.848740469013998*^9}, 3.84874061660666*^9, {3.8487408915102777`*^9, 
   3.848740944680684*^9}, {3.848741345328248*^9, 3.84874134884157*^9}, {
   3.848741403152088*^9, 3.84874140492177*^9}, {3.8487414820593843`*^9, 
   3.848741490170701*^9}, {3.848741561913463*^9, 3.848741578018742*^9}, {
   3.8487416271858883`*^9, 3.848741637898917*^9}, {3.848741750137808*^9, 
   3.848741760418791*^9}, 3.848742242634536*^9, {3.848742350258588*^9, 
   3.848742367204965*^9}, {3.848746327321652*^9, 3.848746346779354*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"0d8d7706-d4b0-4ce1-94d3-7f038669e3d1"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox["\<\"Conic 1-4:\"\>",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontWeight->Bold,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257147336*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"d8a5e8c4-6012-48c7-8ba4-9b8517690fda"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Equation: \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"b", "-", "c"}], ")"}]}]}],
  SequenceForm[
  "      Equation: ", $CellContext`a ($CellContext`a - $CellContext`b - \
$CellContext`c) ($CellContext`b - $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.86078025714782*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"2d82e00c-4db8-456a-8e3c-47bff39353b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Center: \"\>", "\[InvisibleSpace]", 
   RowBox[{"2", " ", "a", " ", "b", " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", "c"}], ")"}], "2"], " ", "c"}], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Center: ", 
   2 $CellContext`a $CellContext`b ($CellContext`a - $CellContext`b - \
$CellContext`c) ($CellContext`b - $CellContext`c)^2 $CellContext`c, "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257151339*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"c045066e-696b-4142-ada2-fdbc8c46a349"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"2 a b c (b-c)^2 (a-b-c)\"\>",
    TeXForm[
    2 $CellContext`a $CellContext`b ($CellContext`a - $CellContext`b - \
$CellContext`c) ($CellContext`b - $CellContext`c)^2 $CellContext`c],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[
   2 $CellContext`a $CellContext`b ($CellContext`a - $CellContext`b - \
$CellContext`c) ($CellContext`b - $CellContext`c)^2 $CellContext`c]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257152668*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"33f7a78c-323e-4371-a418-f0f5cbda9cb9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      center 6-9-13: \"\>", "\[InvisibleSpace]", 
   "2.64313512124520367695852712502578353297`20."}],
  SequenceForm[
  "      center 6-9-13: ", 2.64313512124520367695852712502578353297`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257153599*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"50dca7f9-b635-416f-be4c-9a1646b1fe39"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Persp: \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"b", "-", "c"}], ")"}]}], "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Persp: ", $CellContext`a ($CellContext`a - $CellContext`b - \
$CellContext`c) ($CellContext`b - $CellContext`c), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.86078025715451*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"42396b8b-3067-4943-93cc-fe959b594d57"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      persp  6-9-13: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "18.02995743420835365353852431714016624279`20."}]}],
  SequenceForm[
  "      persp  6-9-13: ", -18.02995743420835365353852431714016624279`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257155364*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"db503aac-d095-4ecb-a58b-9b708242dab4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th: \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"b", " ", "c", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"b", "+", "c"}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}]], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      4th: ", $CellContext`b^(-1) $CellContext`c^(-1)/(
   2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`a^2 \
($CellContext`b + $CellContext`c) + ($CellContext`b - $CellContext`c)^2 \
($CellContext`b + $CellContext`c)), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257156294*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"3e30ea19-8657-42f8-a565-34e885730680"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"b c \\\\left(a^2 (-(b+c))+2 a b c+(b-c)^2 \
(b+c)\\\\right)\"\>",
    TeXForm[$CellContext`b $CellContext`c (
      2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`a^2 \
($CellContext`b + $CellContext`c) + ($CellContext`b - $CellContext`c)^2 \
($CellContext`b + $CellContext`c))],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[$CellContext`b $CellContext`c (
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`a^2 \
($CellContext`b + $CellContext`c) + ($CellContext`b - $CellContext`c)^2 \
($CellContext`b + $CellContext`c))]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257157339*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"502e66a9-879b-4e99-8923-479b2fd20cce"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "10.96288965341694369952332401552616628149`20."}],
  SequenceForm[
  "      4th 6-9-13: ", 10.96288965341694369952332401552616628149`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257164283*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"25b3a146-0637-4d54-9cf7-a302b8fc8c88"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th: \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"a", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"], "-", 
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}]], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Steiner 4th: ", $CellContext`a^(-1)/($CellContext`b^2 + \
$CellContext`c^2 - $CellContext`a ($CellContext`b + $CellContext`c)), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257165193*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"e8f73d09-982a-4769-b77e-c62bf07dee2f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"a \\\\left(-a (b+c)+b^2+c^2\\\\right)\"\>",
    TeXForm[$CellContext`a ($CellContext`b^2 + $CellContext`c^2 - \
$CellContext`a ($CellContext`b + $CellContext`c))],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[$CellContext`a ($CellContext`b^2 + $CellContext`c^2 - \
$CellContext`a ($CellContext`b + $CellContext`c))]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257166245*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"e45452b0-6996-48b0-9d7a-a677573c6800"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "3.0159068831735255982426357062780509746`20."}],
  SequenceForm[
  "      Steiner 4th 6-9-13: ", 3.0159068831735255982426357062780509746`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257167212*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"06cbae8f-0294-4b5e-9ae5-8df7d04c6e05"],

Cell[BoxData[
 StyleBox["\<\"Conic 1-10:\"\>",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontWeight->Bold,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257168045*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"3d306913-0c46-4ae7-88ef-ac629f367859"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Equation: \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}]}],
  SequenceForm[
  "      Equation: ", $CellContext`a (-$CellContext`b^2 + $CellContext`c^2)],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257168954*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"d4d91e1c-511b-4242-a54d-d26b29c3152d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Center: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "a"}], " ", 
    RowBox[{"(", 
     RowBox[{"a", "+", "b"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"a", "+", "c"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", "c"}], ")"}]}], "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Center: ", -$CellContext`a ($CellContext`a + $CellContext`b) \
($CellContext`b - $CellContext`c)^2 ($CellContext`a + $CellContext`c) \
($CellContext`b + $CellContext`c), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.86078025716989*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"872c8b2c-1df9-44bf-9d65-6a3d8e569379"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"-a (a+b) (a+c) (b-c)^2 (b+c)\"\>",
    TeXForm[-$CellContext`a ($CellContext`a + $CellContext`b) ($CellContext`b - \
$CellContext`c)^2 ($CellContext`a + $CellContext`c) ($CellContext`b + \
$CellContext`c)],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[-$CellContext`a ($CellContext`a + $CellContext`b) ($CellContext`b - \
$CellContext`c)^2 ($CellContext`a + $CellContext`c) ($CellContext`b + \
$CellContext`c)]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257170871*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"8b683597-c63a-4de4-a1ab-3e429e8452bd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      center 6-9-13: \"\>", "\[InvisibleSpace]", 
   "1.15788717467393096857586853412826755688`20."}],
  SequenceForm[
  "      center 6-9-13: ", 1.15788717467393096857586853412826755688`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257171742*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"f215fe54-971d-4208-bfe0-a03484f2c0d3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Persp: \"\>", "\[InvisibleSpace]", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}], "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Persp: ", $CellContext`a (-$CellContext`b^2 + $CellContext`c^2), 
   "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802571726093`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"e9d58275-98c8-4e4a-8c36-f3520f468f7c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      persp  6-9-13: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "49.58238294407297254723094187213545716766`20."}]}],
  SequenceForm[
  "      persp  6-9-13: ", -49.58238294407297254723094187213545716766`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802571735067`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"4fa35961-f9b1-41f8-9f34-f0644d045304"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th: \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{"b", " ", "c", " ", 
     RowBox[{"(", 
      RowBox[{"b", "+", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "b"}], " ", "c"}], "+", 
       RowBox[{"2", " ", 
        SubscriptBox["S", "A"]}]}], ")"}]}]], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      4th: ", $CellContext`b^(-1) $CellContext`c^(-1) ($CellContext`b + \
$CellContext`c)^(-1)/(-$CellContext`b $CellContext`c + 
   2 Subscript[$CellContext`S, $CellContext`A]), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257174819*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"f2083655-5071-4d2b-8ce6-26cc3f1ce20f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"b c (b+c) \\\\left(2 S_A-b c\\\\right)\"\>",
    TeXForm[$CellContext`b $CellContext`c ($CellContext`b + $CellContext`c) \
(-$CellContext`b $CellContext`c + 
      2 Subscript[$CellContext`S, $CellContext`A])],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[$CellContext`b $CellContext`c ($CellContext`b + $CellContext`c) \
(-$CellContext`b $CellContext`c + 
     2 Subscript[$CellContext`S, $CellContext`A])]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257176373*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"d8ce5e6c-98c6-4654-9fa3-13faad62fa20"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "4.49591574395950858662804022787162191216`20."}],
  SequenceForm[
  "      4th 6-9-13: ", 4.49591574395950858662804022787162191216`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257177259*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"b58cac0b-20c1-4714-ad99-73895eadaf8d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th: \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"b", "+", "c"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], "+", 
       RowBox[{"b", " ", "c"}]}], ")"}]}]], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Steiner 4th: ", ($CellContext`b + \
$CellContext`c)^(-1)/(-$CellContext`a^2 + $CellContext`b $CellContext`c), 
   "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802571781588`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"4866bf9d-b185-4110-91dd-7bf149301281"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"(b+c) \\\\left(b c-a^2\\\\right)\"\>",
    TeXForm[($CellContext`b + $CellContext`c) (-$CellContext`a^2 + \
$CellContext`b $CellContext`c)],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[($CellContext`b + $CellContext`c) (-$CellContext`a^2 + \
$CellContext`b $CellContext`c)]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802571792192`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"68bf6cf3-54ba-4c75-b6d7-ee49e9a734ba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.25204676706458037428862310790551017176`20."}]}],
  SequenceForm[
  "      Steiner 4th 6-9-13: ", -0.25204676706458037428862310790551017176`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257180174*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"5399d8d7-c222-43ed-93dd-aa061b941c1a"],

Cell[BoxData[
 StyleBox["\<\"Conic 2-4:\"\>",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontWeight->Bold,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257181088*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"c68dd36a-64ea-40dd-a8b7-f26aa7376cca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Equation: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["b", "2"], "-", 
    SuperscriptBox["c", "2"]}]}],
  SequenceForm["      Equation: ", $CellContext`b^2 - $CellContext`c^2],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802571820593`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"986bf14c-79e5-4651-8664-2bdd11afe1bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Center: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], "2"]}], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Center: ", (-2) ($CellContext`b^2 - $CellContext`c^2)^2, "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257183025*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"9f6b3b2f-2b25-48e4-9464-cad8d144a67e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"-2 \\\\left(b^2-c^2\\\\right)^2\"\>",
    TeXForm[(-2) ($CellContext`b^2 - $CellContext`c^2)^2],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[(-2) ($CellContext`b^2 - $CellContext`c^2)^2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257183997*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"5ef61900-b801-447a-b427-912195b3e7e3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      center 6-9-13: \"\>", "\[InvisibleSpace]", 
   "2.22468846190902112965942604656096158608`20."}],
  SequenceForm[
  "      center 6-9-13: ", 2.22468846190902112965942604656096158608`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257184918*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"a31e5cab-51ba-445b-a9b3-fd1d059b0156"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Persp: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["b", "2"], "-", 
    SuperscriptBox["c", "2"]}], "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm["      Persp: ", $CellContext`b^2 - $CellContext`c^2, "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802571859503`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"abd9f158-2a60-477c-a293-398a4dbdd92a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      persp  6-9-13: \"\>", "\[InvisibleSpace]", 
   "2.29390142021720969089390142021720969089`20."}],
  SequenceForm[
  "      persp  6-9-13: ", 2.29390142021720969089390142021720969089`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802571869173`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"a7cab399-e37b-47d2-89eb-f03f86ada4cd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th: \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["b", "4"]}], "-", 
     SuperscriptBox["c", "4"], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}]], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      4th: ", (-$CellContext`b^4 - $CellContext`c^4 + $CellContext`a^2 \
($CellContext`b^2 + $CellContext`c^2))^(-1), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257193224*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"4f8094c1-c940-4b5d-819c-5fb04c3d7f2c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"a^2 \\\\left(b^2+c^2\\\\right)-b^4-c^4\"\>",
    TeXForm[-$CellContext`b^4 - $CellContext`c^4 + $CellContext`a^2 \
($CellContext`b^2 + $CellContext`c^2)],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[-$CellContext`b^4 - $CellContext`c^4 + $CellContext`a^2 \
($CellContext`b^2 + $CellContext`c^2)]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802571944513`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"e7d0bd10-0faf-4c00-8f5e-7b3ecabfb254"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "10.1259963347445786049251218585965223877`20."}],
  SequenceForm[
  "      4th 6-9-13: ", 10.1259963347445786049251218585965223877`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257195383*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"4ae71dab-45c9-4255-8ea4-fc43f1369302"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th: \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"]}], "-", 
     SuperscriptBox["b", "2"], "-", 
     SuperscriptBox["c", "2"]}]], "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Steiner 4th: ", (
    2 $CellContext`a^2 - $CellContext`b^2 - $CellContext`c^2)^(-1), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257227318*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"8bd9efc7-2743-403f-8aa4-8fd0da079392"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"2 a^2-b^2-c^2\"\>",
    TeXForm[2 $CellContext`a^2 - $CellContext`b^2 - $CellContext`c^2],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[2 $CellContext`a^2 - $CellContext`b^2 - $CellContext`c^2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257228483*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"ee0f8f97-3376-4758-81b7-61c0d12e0d4a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "1.82000813132932401817781729687231559508`20."}],
  SequenceForm[
  "      Steiner 4th 6-9-13: ", 1.82000813132932401817781729687231559508`20.],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802572293587`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"1ade0fb1-d8ec-447b-94d7-6730e9c05a76"],

Cell[BoxData[
 StyleBox["\<\"Conic 2-15:\"\>",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontWeight->Bold,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257230322*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"fcaa766f-4f09-46ef-a2f6-627188f7a7c6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Equation: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["S", "A", "2"]}]}], ")"}]}]}],
  SequenceForm[
  "      Equation: ", -$CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2) \
($CellContext`b^2 $CellContext`c^2 - 4 
    Subscript[$CellContext`S, $CellContext`A]^2)],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257231497*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"d90edc24-b1fb-4c3f-86ef-409c1c321b05"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Center: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["a", "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["c", "2"]}], "-", 
       RowBox[{"4", " ", 
        SubsuperscriptBox["S", "A", "2"]}]}], ")"}], "2"]}], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Center: ", (-2) $CellContext`a^4 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^2 $CellContext`c^2 - 4 
     Subscript[$CellContext`S, $CellContext`A]^2)^2, "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257266026*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"8aa6cbcd-4321-4dd0-afd0-f6e9e729f345"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"-2 a^4 \\\\left(b^2-c^2\\\\right)^2 \\\\left(b^2 \
c^2-4 S_A^2\\\\right){}^2\"\>",
    TeXForm[(-2) $CellContext`a^4 ($CellContext`b^2 - $CellContext`c^2)^2 \
($CellContext`b^2 $CellContext`c^2 - 4 
       Subscript[$CellContext`S, $CellContext`A]^2)^2],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[(-2) $CellContext`a^4 ($CellContext`b^2 - $CellContext`c^2)^2 \
($CellContext`b^2 $CellContext`c^2 - 4 
      Subscript[$CellContext`S, $CellContext`A]^2)^2]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257267638*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"9d6f66b8-15fd-4dda-aea0-0dc027d7fe63"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      center 6-9-13: \"\>", "\[InvisibleSpace]", 
   "4.00655348602883420224103176683327604864`20."}],
  SequenceForm[
  "      center 6-9-13: ", 4.00655348602883420224103176683327604864`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257268865*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"15ec6364-23f4-4aa9-922b-159b0a21c865"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Persp: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["S", "A", "2"]}]}], ")"}]}], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Persp: ", -$CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2) \
($CellContext`b^2 $CellContext`c^2 - 4 
    Subscript[$CellContext`S, $CellContext`A]^2), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257269836*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"c2ce4b5c-44e4-42bd-a8fc-eb5fe9aeed69"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      persp  6-9-13: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "63.10455084828596542174199654653787554997`20."}]}],
  SequenceForm[
  "      persp  6-9-13: ", -63.10455084828596542174199654653787554997`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257270769*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"76ff0eb1-87ac-4f4f-b6e3-8e55e2bedb4b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "4"], "+", 
           SuperscriptBox["c", "4"]}], ")"}]}]}], ")"}]}]]}], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      4th: ", -$CellContext`b^(-2) $CellContext`c^(-2)/((-2) \
$CellContext`a^6 + 
   2 $CellContext`a^4 ($CellContext`b^2 + $CellContext`c^2) + \
($CellContext`b^2 - $CellContext`c^2)^2 ($CellContext`b^2 + $CellContext`c^2) - \
$CellContext`a^2 ($CellContext`b^4 + $CellContext`c^4)), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257279755*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"d75ef192-a6e3-4711-a127-f0199f003532"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"-b^2 c^2 \\\\left(-2 a^6+2 a^4 \
\\\\left(b^2+c^2\\\\right)-a^2 \
\\\\left(b^4+c^4\\\\right)+\\\\left(b^2-c^2\\\\right)^2 \
\\\\left(b^2+c^2\\\\right)\\\\right)\"\>",
    TeXForm[-$CellContext`b^2 $CellContext`c^2 ((-2) $CellContext`a^6 + 
      2 $CellContext`a^4 ($CellContext`b^2 + $CellContext`c^2) + \
($CellContext`b^2 - $CellContext`c^2)^2 ($CellContext`b^2 + $CellContext`c^2) - \
$CellContext`a^2 ($CellContext`b^4 + $CellContext`c^4))],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[-$CellContext`b^2 $CellContext`c^2 ((-2) $CellContext`a^6 + 
     2 $CellContext`a^4 ($CellContext`b^2 + $CellContext`c^2) + \
($CellContext`b^2 - $CellContext`c^2)^2 ($CellContext`b^2 + $CellContext`c^2) - \
$CellContext`a^2 ($CellContext`b^4 + $CellContext`c^4))]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257312207*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"b7a5c913-a03c-4ddc-ad89-2a8c2927ffe0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "14.19292674570118888652144301416092707545`20."}],
  SequenceForm[
  "      4th 6-9-13: ", 14.19292674570118888652144301416092707545`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257313381*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"4cda74a4-3062-4209-9289-dab243ce576d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th: \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox["a", "6"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "4"], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "6"], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}]}]], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Steiner 4th: ", ((-2) $CellContext`b^2 $CellContext`c^2 \
($CellContext`b^2 - $CellContext`c^2)^2 + $CellContext`a^6 ($CellContext`b^2 + \
$CellContext`c^2) - 
    2 $CellContext`a^4 ($CellContext`b^4 + $CellContext`c^4) + \
$CellContext`a^2 ($CellContext`b^6 + $CellContext`c^6))^(-1), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257314477*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"6960d060-5242-45a6-a660-2edeaad84b48"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"a^6 \\\\left(b^2+c^2\\\\right)-2 a^4 \
\\\\left(b^4+c^4\\\\right)+a^2 \\\\left(b^6+c^6\\\\right)-2 b^2 c^2 \
\\\\left(b^2-c^2\\\\right)^2\"\>",
    TeXForm[(-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 + $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2) - 
     2 $CellContext`a^4 ($CellContext`b^4 + $CellContext`c^4) + \
$CellContext`a^2 ($CellContext`b^6 + $CellContext`c^6)],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[(-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 + $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2) - 
    2 $CellContext`a^4 ($CellContext`b^4 + $CellContext`c^4) + \
$CellContext`a^2 ($CellContext`b^6 + $CellContext`c^6)]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257347323*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"3d533c38-1502-4df9-9f39-cb3276368004"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "5.3837381795689501633410287374169445202`20."}],
  SequenceForm[
  "      Steiner 4th 6-9-13: ", 5.3837381795689501633410287374169445202`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257348482*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"784a9f6a-28b9-4525-a349-95bf2c3f95c3"],

Cell[BoxData[
 StyleBox["\<\"Conic 3-4:\"\>",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontWeight->Bold,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.86078025734934*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"562ca321-553c-47a4-b445-6452fd12ab9a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Equation: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    SubscriptBox["S", "A"]}]}],
  SequenceForm[
  "      Equation: ", (-2) $CellContext`a^2 ($CellContext`b^2 - \
$CellContext`c^2) Subscript[$CellContext`S, $CellContext`A]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257350371*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"60a9dbbd-7d8f-4f55-9f49-b25c752ccb2f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Center: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "4"}], " ", 
    SuperscriptBox["a", "2"], " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
    SubscriptBox["S", "A"]}], "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Center: ", (-4) $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 \
($CellContext`b^2 - $CellContext`c^2)^2 
   Subscript[$CellContext`S, $CellContext`A], "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257351424*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"134ea44a-7ae6-409c-9265-d02dc8088ea1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"-4 a^2 b^2 c^2 S_A \\\\left(b^2-c^2\\\\right)^2\"\>",
    TeXForm[(-4) $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 \
($CellContext`b^2 - $CellContext`c^2)^2 
     Subscript[$CellContext`S, $CellContext`A]],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[(-4) $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 \
($CellContext`b^2 - $CellContext`c^2)^2 
    Subscript[$CellContext`S, $CellContext`A]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257352425*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"824bee7b-9e94-48d7-86d8-bc764ac7b703"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      center 6-9-13: \"\>", "\[InvisibleSpace]", 
   "3.49027170168223202148485465790792668122`20."}],
  SequenceForm[
  "      center 6-9-13: ", 3.49027170168223202148485465790792668122`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802573533907`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"91132479-3705-4a0f-83cd-bb994e3ed6b6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Persp: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    SubscriptBox["S", "A"]}], "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Persp: ", (-2) $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)
     Subscript[$CellContext`S, $CellContext`A], "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257354343*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"3a2ed37f-2569-4349-9530-f287f59a57a9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      persp  6-9-13: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "5.07685643542182589718058447877367838944`20."}]}],
  SequenceForm[
  "      persp  6-9-13: ", -5.07685643542182589718058447877367838944`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257355261*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"c4e86e9e-93c4-4b47-b608-2cebaf23e010"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th: \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["a", "4"]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"]}], ")"}], "2"], "+", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}]}]], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      4th: ", $CellContext`b^(-2) $CellContext`c^(-2)/((-2) \
$CellContext`a^4 + ($CellContext`b^2 - $CellContext`c^2)^2 + $CellContext`a^2 \
($CellContext`b^2 + $CellContext`c^2)), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257387783*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"f1c82784-621c-434c-82b8-f691bc982b84"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"b^2 c^2 \\\\left(-2 a^4+a^2 \
\\\\left(b^2+c^2\\\\right)+\\\\left(b^2-c^2\\\\right)^2\\\\right)\"\>",
    TeXForm[$CellContext`b^2 $CellContext`c^2 ((-2) $CellContext`a^4 + \
($CellContext`b^2 - $CellContext`c^2)^2 + $CellContext`a^2 ($CellContext`b^2 + \
$CellContext`c^2))],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[$CellContext`b^2 $CellContext`c^2 ((-2) $CellContext`a^4 + \
($CellContext`b^2 - $CellContext`c^2)^2 + $CellContext`a^2 ($CellContext`b^2 + \
$CellContext`c^2))]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257389032*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"ce20978a-5fa9-42fe-a074-98c8a77539d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "12.65716281429100038857597908129045257798`20."}],
  SequenceForm[
  "      4th 6-9-13: ", 12.65716281429100038857597908129045257798`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257389934*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"358ec6c7-1a48-41d8-b0b3-2900e7d1bb52"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th: \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "4"], "+", 
       SuperscriptBox["c", "4"], "-", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}]}]], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Steiner 4th: ", $CellContext`a^(-2)/($CellContext`b^4 + \
$CellContext`c^4 - $CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2)), 
   "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257390834*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"3aebb265-89d4-47c0-a8bd-331b0553826e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"a^2 \\\\left(-a^2 \
\\\\left(b^2+c^2\\\\right)+b^4+c^4\\\\right)\"\>",
    TeXForm[$CellContext`a^2 ($CellContext`b^4 + $CellContext`c^4 - \
$CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2))],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[$CellContext`a^2 ($CellContext`b^4 + $CellContext`c^4 - \
$CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2))]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802573918047`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"d57f059b-d223-4acd-a403-959a641f125a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "5.59795717176572455690502904144193171013`20."}],
  SequenceForm[
  "      Steiner 4th 6-9-13: ", 5.59795717176572455690502904144193171013`20.],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802573926697`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"d56abed0-5698-40ed-9b98-efb211a75267"],

Cell[BoxData[
 StyleBox["\<\"Conic 3-15:\"\>",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontWeight->Bold,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.86078025746894*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"87eb3cc9-aa7a-4a8b-a726-8f0a76ff9ee1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Equation: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "4"}], " ", 
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    SubscriptBox["S", "A"], " ", 
    RowBox[{"(", 
     RowBox[{"S", "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       SubscriptBox["S", "A"]}]}], ")"}]}]}],
  SequenceForm[
  "      Equation: ", (-4) $CellContext`a^2 ($CellContext`b^2 - \
$CellContext`c^2) 
   Subscript[$CellContext`S, $CellContext`A] ($CellContext`S + 
    3^Rational[1, 2] Subscript[$CellContext`S, $CellContext`A])],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257470076*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"a15670f9-28e5-4434-aad8-46bec82aa56c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Center: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "16"}], " ", 
    SuperscriptBox["a", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
    SubscriptBox["S", "A"], " ", 
    RowBox[{"(", 
     RowBox[{"S", "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       SubscriptBox["S", "A"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"], " ", "S"}], "+", 
      RowBox[{"2", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["a", "2"], " ", 
       SubsuperscriptBox["S", "A", "2"]}]}], ")"}]}], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Center: ", (-16) $CellContext`a^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 
   Subscript[$CellContext`S, $CellContext`A] ($CellContext`S + 
    3^Rational[1, 2] 
     Subscript[$CellContext`S, $CellContext`A]) ($CellContext`b^2 \
$CellContext`c^2 $CellContext`S + 
    2 3^Rational[1, 2] $CellContext`a^2 
     Subscript[$CellContext`S, $CellContext`A]^2), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802575421886`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"0163916e-ea06-4ce7-9f48-d1abd40b8cec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"-16 a^2 S_A \\\\left(\\\\sqrt{3} S_A+S\\\\right) \\\
\\left(b^2-c^2\\\\right)^2 \\\\left(2 \\\\sqrt{3} a^2 S_A^2+b^2 c^2 \
S\\\\right)\"\>",
    TeXForm[(-16) $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 
     Subscript[$CellContext`S, $CellContext`A] ($CellContext`S + 
      3^Rational[1, 2] 
       Subscript[$CellContext`S, $CellContext`A]) ($CellContext`b^2 \
$CellContext`c^2 $CellContext`S + 
      2 3^Rational[1, 2] $CellContext`a^2 
       Subscript[$CellContext`S, $CellContext`A]^2)],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[(-16) $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 
    Subscript[$CellContext`S, $CellContext`A] ($CellContext`S + 
     3^Rational[1, 2] 
      Subscript[$CellContext`S, $CellContext`A]) ($CellContext`b^2 \
$CellContext`c^2 $CellContext`S + 
     2 3^Rational[1, 2] $CellContext`a^2 
      Subscript[$CellContext`S, $CellContext`A]^2)]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257573389*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"c1d59bf6-37a5-44e0-bba0-8e1d9e5843eb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      center 6-9-13: \"\>", "\[InvisibleSpace]", 
   "3.42507353012236429035672307503167167233`20."}],
  SequenceForm[
  "      center 6-9-13: ", 3.42507353012236429035672307503167167233`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257574781*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"9661e836-656d-4bf5-ab08-765d7b32f1b7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Persp: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "4"}], " ", 
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    SubscriptBox["S", "A"], " ", 
    RowBox[{"(", 
     RowBox[{"S", "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       SubscriptBox["S", "A"]}]}], ")"}]}], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Persp: ", (-4) $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)
     Subscript[$CellContext`S, $CellContext`A] ($CellContext`S + 
    3^Rational[1, 2] Subscript[$CellContext`S, $CellContext`A]), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802575757637`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"426cdff8-7d04-4fbf-b2a8-bab07eaebd29"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      persp  6-9-13: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "24.95680600520235334940688338995261802557`20."}]}],
  SequenceForm[
  "      persp  6-9-13: ", -24.95680600520235334940688338995261802557`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257576782*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"0015ecbc-6af5-4064-99e8-c58588c0cc3a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th: \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["a", "6"]}], "+", 
          RowBox[{
           SuperscriptBox["a", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["a", "4"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"]}], ")"}], "2"], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}], " ", "S"}]}], 
      ")"}]}]], "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      4th: ", $CellContext`b^(-2) $CellContext`c^(-2)/(
   3^Rational[
      1, 2] ((-2) $CellContext`a^6 + $CellContext`a^4 ($CellContext`b^2 + \
$CellContext`c^2) + ($CellContext`b^2 - $CellContext`c^2)^2 ($CellContext`b^2 + \
$CellContext`c^2)) + 
   2 ((-2) $CellContext`a^4 + ($CellContext`b^2 - $CellContext`c^2)^2 + \
$CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2)) $CellContext`S), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802576814528`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"da8a6684-105e-4d0c-a6c3-d778dbf54481"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"b^2 c^2 \\\\left(\\\\sqrt{3} \\\\left(-2 a^6+a^4 \\\
\\left(b^2+c^2\\\\right)+\\\\left(b^2-c^2\\\\right)^2 \
\\\\left(b^2+c^2\\\\right)\\\\right)+2 S \\\\left(-2 a^4+a^2 \\\\left(b^2+c^2\
\\\\right)+\\\\left(b^2-c^2\\\\right)^2\\\\right)\\\\right)\"\>",
    TeXForm[$CellContext`b^2 $CellContext`c^2 (
      3^Rational[
         1, 2] ((-2) $CellContext`a^6 + $CellContext`a^4 ($CellContext`b^2 + \
$CellContext`c^2) + ($CellContext`b^2 - $CellContext`c^2)^2 ($CellContext`b^2 + \
$CellContext`c^2)) + 
      2 ((-2) $CellContext`a^4 + ($CellContext`b^2 - $CellContext`c^2)^2 + \
$CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2)) $CellContext`S)],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[$CellContext`b^2 $CellContext`c^2 (
     3^Rational[
        1, 2] ((-2) $CellContext`a^6 + $CellContext`a^4 ($CellContext`b^2 + \
$CellContext`c^2) + ($CellContext`b^2 - $CellContext`c^2)^2 ($CellContext`b^2 + \
$CellContext`c^2)) + 
     2 ((-2) $CellContext`a^4 + ($CellContext`b^2 - $CellContext`c^2)^2 + \
$CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2)) $CellContext`S)]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257711933*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"5f663857-7802-4bee-b1da-5698e13cfa2c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "13.55623747311197826449337975446997991775`20."}],
  SequenceForm[
  "      4th 6-9-13: ", 13.55623747311197826449337975446997991775`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802577131653`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"a34a2179-b986-4323-a96a-26c94a5759e0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th: \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     RowBox[{
      SqrtBox["3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "4"], "-", 
           RowBox[{
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["c", "2"]}], "+", 
           SuperscriptBox["c", "4"]}], ")"}]}]}], ")"}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "4"]}], "-", 
        SuperscriptBox["c", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}], " ", "S"}]}]], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Steiner 4th: ", (
    3^Rational[1, 2] (
      2 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 - $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2) - \
$CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 ($CellContext`b^2 + \
$CellContext`c^2) + 
      2 $CellContext`a^4 ($CellContext`b^4 - $CellContext`b^2 \
$CellContext`c^2 + $CellContext`c^4)) - 
    2 $CellContext`a^2 (-$CellContext`b^4 - $CellContext`c^4 + \
$CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2)) $CellContext`S)^(-1), 
   "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257832797*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"a6a90dd7-8385-4490-9a7f-794d7b5f8f54"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"\\\\sqrt{3} \\\\left(a^6 \\\\left(-\\\\left(b^2+c^2\
\\\\right)\\\\right)+2 a^4 \\\\left(b^4-b^2 c^2+c^4\\\\right)-a^2 \
\\\\left(b^2-c^2\\\\right)^2 \\\\left(b^2+c^2\\\\right)+2 b^2 c^2 \
\\\\left(b^2-c^2\\\\right)^2\\\\right)-2 a^2 S \\\\left(a^2 \
\\\\left(b^2+c^2\\\\right)-b^4-c^4\\\\right)\"\>",
    TeXForm[
    3^Rational[1, 2] (
       2 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 - $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2) - \
$CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 ($CellContext`b^2 + \
$CellContext`c^2) + 
       2 $CellContext`a^4 ($CellContext`b^4 - $CellContext`b^2 \
$CellContext`c^2 + $CellContext`c^4)) - 
     2 $CellContext`a^2 (-$CellContext`b^4 - $CellContext`c^4 + \
$CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2)) $CellContext`S],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[
   3^Rational[1, 2] (
      2 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 - $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2) - \
$CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 ($CellContext`b^2 + \
$CellContext`c^2) + 
      2 $CellContext`a^4 ($CellContext`b^4 - $CellContext`b^2 \
$CellContext`c^2 + $CellContext`c^4)) - 
    2 $CellContext`a^2 (-$CellContext`b^4 - $CellContext`c^4 + \
$CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2)) $CellContext`S]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802578635387`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"ef0dae05-f8e2-4872-9d0e-25d07662a41f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "4.55320743237377058208308343681443627242`20."}],
  SequenceForm[
  "      Steiner 4th 6-9-13: ", 4.55320743237377058208308343681443627242`20.],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802578650084`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"58283292-c0ed-490f-8c93-e197330397bc"],

Cell[BoxData[
 StyleBox["\<\"Conic 3-16:\"\>",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontWeight->Bold,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257944271*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"c681820a-ba7b-4a47-93b8-ad256d7cfccb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Equation: \"\>", "\[InvisibleSpace]", 
   RowBox[{"4", " ", 
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    SubscriptBox["S", "A"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "S"}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       SubscriptBox["S", "A"]}]}], ")"}]}]}],
  SequenceForm[
  "      Equation: ", 
   4 $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2) 
   Subscript[$CellContext`S, $CellContext`A] (-$CellContext`S + 
    3^Rational[1, 2] Subscript[$CellContext`S, $CellContext`A])],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780257945446*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"db92c0db-6ac0-4031-8532-e8ffdb86884e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Center: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", "16"}], " ", 
    SuperscriptBox["a", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
    SubscriptBox["S", "A"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "S"}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       SubscriptBox["S", "A"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["b", "2"]}], " ", 
       SuperscriptBox["c", "2"], " ", "S"}], "+", 
      RowBox[{"2", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["a", "2"], " ", 
       SubsuperscriptBox["S", "A", "2"]}]}], ")"}]}], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Center: ", (-16) $CellContext`a^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 
   Subscript[$CellContext`S, $CellContext`A] (-$CellContext`S + 
    3^Rational[1, 2] 
     Subscript[$CellContext`S, $CellContext`A]) (-$CellContext`b^2 \
$CellContext`c^2 $CellContext`S + 
    2 3^Rational[1, 2] $CellContext`a^2 
     Subscript[$CellContext`S, $CellContext`A]^2), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780258014881*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"0f93b6c4-14cb-44d8-88ae-b7ed916f0a52"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"-16 a^2 S_A \\\\left(\\\\sqrt{3} S_A-S\\\\right) \\\
\\left(b^2-c^2\\\\right)^2 \\\\left(2 \\\\sqrt{3} a^2 S_A^2-b^2 c^2 \
S\\\\right)\"\>",
    TeXForm[(-16) $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 
     Subscript[$CellContext`S, $CellContext`A] (-$CellContext`S + 
      3^Rational[1, 2] 
       Subscript[$CellContext`S, $CellContext`A]) (-$CellContext`b^2 \
$CellContext`c^2 $CellContext`S + 
      2 3^Rational[1, 2] $CellContext`a^2 
       Subscript[$CellContext`S, $CellContext`A]^2)],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[(-16) $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 
    Subscript[$CellContext`S, $CellContext`A] (-$CellContext`S + 
     3^Rational[1, 2] 
      Subscript[$CellContext`S, $CellContext`A]) (-$CellContext`b^2 \
$CellContext`c^2 $CellContext`S + 
     2 3^Rational[1, 2] $CellContext`a^2 
      Subscript[$CellContext`S, $CellContext`A]^2)]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780258045354*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"8948e82b-d8d6-40f3-a381-fdb693d45caf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      center 6-9-13: \"\>", "\[InvisibleSpace]", 
   "3.31447618826675385230925586259679776595`20."}],
  SequenceForm[
  "      center 6-9-13: ", 3.31447618826675385230925586259679776595`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802580466747`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"1c6a1b39-ddb2-451c-b488-0d306c1d1c24"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Persp: \"\>", "\[InvisibleSpace]", 
   RowBox[{"4", " ", 
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    SubscriptBox["S", "A"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "S"}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       SubscriptBox["S", "A"]}]}], ")"}]}], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Persp: ", 4 $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2) 
   Subscript[$CellContext`S, $CellContext`A] (-$CellContext`S + 
    3^Rational[1, 2] Subscript[$CellContext`S, $CellContext`A]), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802580476913`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"ac4aba3e-e9ef-43f5-8cff-1ba2f6a3b609"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      persp  6-9-13: \"\>", "\[InvisibleSpace]", 
   "14.80309313435870155504571443240515538055`20."}],
  SequenceForm[
  "      persp  6-9-13: ", 14.80309313435870155504571443240515538055`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780258049036*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"557b6d75-9659-4eab-ac79-92f9337167c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SqrtBox["3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            SuperscriptBox["a", "6"]}], "+", 
           RowBox[{
            SuperscriptBox["a", "4"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "2"], "+", 
              SuperscriptBox["c", "2"]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["b", "2"], "-", 
               SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "2"], "+", 
              SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["a", "4"]}], "-", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"]}], ")"}], "2"], "-", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "2"], "+", 
              SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}], " ", "S"}]}], 
       ")"}]}]]}], "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      4th: ", -$CellContext`b^(-2) $CellContext`c^(-2)/(
   3^Rational[
      1, 2] ((-2) $CellContext`a^6 + $CellContext`a^4 ($CellContext`b^2 + \
$CellContext`c^2) + ($CellContext`b^2 - $CellContext`c^2)^2 ($CellContext`b^2 + \
$CellContext`c^2)) + 
   2 (2 $CellContext`a^4 - ($CellContext`b^2 - $CellContext`c^2)^2 - \
$CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2)) $CellContext`S), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780258135909*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"312e373e-7e3c-4fb7-917a-a4b33c606687"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"-b^2 c^2 \\\\left(\\\\sqrt{3} \\\\left(-2 a^6+a^4 \
\\\\left(b^2+c^2\\\\right)+\\\\left(b^2-c^2\\\\right)^2 \
\\\\left(b^2+c^2\\\\right)\\\\right)+2 S \\\\left(2 a^4-a^2 \
\\\\left(b^2+c^2\\\\right)-\\\\left(b^2-c^2\\\\right)^2\\\\right)\\\\right)\"\
\>",
    TeXForm[-$CellContext`b^2 $CellContext`c^2 (
      3^Rational[
         1, 2] ((-2) $CellContext`a^6 + $CellContext`a^4 ($CellContext`b^2 + \
$CellContext`c^2) + ($CellContext`b^2 - $CellContext`c^2)^2 ($CellContext`b^2 + \
$CellContext`c^2)) + 
      2 (2 $CellContext`a^4 - ($CellContext`b^2 - $CellContext`c^2)^2 - \
$CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2)) $CellContext`S)],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[-$CellContext`b^2 $CellContext`c^2 (
     3^Rational[
        1, 2] ((-2) $CellContext`a^6 + $CellContext`a^4 ($CellContext`b^2 + \
$CellContext`c^2) + ($CellContext`b^2 - $CellContext`c^2)^2 ($CellContext`b^2 + \
$CellContext`c^2)) + 
     2 (2 $CellContext`a^4 - ($CellContext`b^2 - $CellContext`c^2)^2 - \
$CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2)) $CellContext`S)]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780258167088*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"0a7fe40d-2c1a-4b98-8dce-d45a24bbae9d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "14.05353997675646291319931916901126299826`20."}],
  SequenceForm[
  "      4th 6-9-13: ", 14.05353997675646291319931916901126299826`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802581683187`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"e2a8a4f9-c0db-4d9d-b7d3-77c3bffba212"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th: \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     RowBox[{
      SqrtBox["3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"]}], ")"}]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "4"], "-", 
           RowBox[{
            SuperscriptBox["b", "2"], " ", 
            SuperscriptBox["c", "2"]}], "+", 
           SuperscriptBox["c", "4"]}], ")"}]}]}], ")"}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "4"]}], "-", 
        SuperscriptBox["c", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}], " ", "S"}]}]], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Steiner 4th: ", (
    3^Rational[
       1, 2] ((-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 + $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2) + \
$CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 ($CellContext`b^2 + \
$CellContext`c^2) - 
      2 $CellContext`a^4 ($CellContext`b^4 - $CellContext`b^2 \
$CellContext`c^2 + $CellContext`c^4)) - 
    2 $CellContext`a^2 (-$CellContext`b^4 - $CellContext`c^4 + \
$CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2)) $CellContext`S)^(-1), 
   "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780258275381*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"782bfdea-ea16-426d-9245-57d1b93019cf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"\\\\sqrt{3} \\\\left(a^6 \
\\\\left(b^2+c^2\\\\right)-2 a^4 \\\\left(b^4-b^2 c^2+c^4\\\\right)+a^2 \
\\\\left(b^2-c^2\\\\right)^2 \\\\left(b^2+c^2\\\\right)-2 b^2 c^2 \
\\\\left(b^2-c^2\\\\right)^2\\\\right)-2 a^2 S \\\\left(a^2 \
\\\\left(b^2+c^2\\\\right)-b^4-c^4\\\\right)\"\>",
    TeXForm[
    3^Rational[
        1, 2] ((-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 + $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2) + \
$CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 ($CellContext`b^2 + \
$CellContext`c^2) - 
       2 $CellContext`a^4 ($CellContext`b^4 - $CellContext`b^2 \
$CellContext`c^2 + $CellContext`c^4)) - 
     2 $CellContext`a^2 (-$CellContext`b^4 - $CellContext`c^4 + \
$CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2)) $CellContext`S],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[
   3^Rational[
       1, 2] ((-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 + $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2) + \
$CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 ($CellContext`b^2 + \
$CellContext`c^2) - 
      2 $CellContext`a^4 ($CellContext`b^4 - $CellContext`b^2 \
$CellContext`c^2 + $CellContext`c^4)) - 
    2 $CellContext`a^2 (-$CellContext`b^4 - $CellContext`c^4 + \
$CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2)) $CellContext`S]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780258309329*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"5d8a433c-291d-4d8b-a753-2250ed3b7de8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "3.32083640468940820942615912788848287951`20."}],
  SequenceForm[
  "      Steiner 4th 6-9-13: ", 3.32083640468940820942615912788848287951`20.],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780258310791*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"6cb088df-e619-4088-aec0-90db814b8194"],

Cell[BoxData[
 StyleBox["\<\"Conic 6-9:\"\>",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontWeight->Bold,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780258311857*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"a4f3c828-0f65-4447-a636-fa0048795994"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Equation: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"b", "-", "c"}], ")"}]}]}],
  SequenceForm[
  "      Equation: ", -$CellContext`a^2 ($CellContext`a - $CellContext`b - \
$CellContext`c) ($CellContext`b - $CellContext`c)],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780258312999*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"e2943465-9497-46d3-b40a-032bb4dfe03d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Center: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", " ", "b", " ", "c"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"]}], "+", 
         RowBox[{"b", " ", "c"}]}], ")"}]}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SubscriptBox["S", "\[Omega]"]}]}], ")"}]}], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Center: ", -$CellContext`a^2 ($CellContext`a - $CellContext`b - \
$CellContext`c) ($CellContext`b - $CellContext`c)^2 ($CellContext`a \
$CellContext`b $CellContext`c - ($CellContext`b + $CellContext`c) (
     2 $CellContext`a^2 + $CellContext`b $CellContext`c) + 
    2 $CellContext`a Subscript[$CellContext`S, $CellContext`\[Omega]]), "::"],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.86078025834522*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"510b0d59-1b9a-49cb-ac24-e2f81bb1c456"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"-a^2 (b-c)^2 (a-b-c) \\\\left(-(b+c) \\\\left(2 \
a^2+b c\\\\right)+a b c+2 a S_{\\\\omega }\\\\right)\"\>",
    TeXForm[-$CellContext`a^2 ($CellContext`a - $CellContext`b - \
$CellContext`c) ($CellContext`b - $CellContext`c)^2 ($CellContext`a \
$CellContext`b $CellContext`c - ($CellContext`b + $CellContext`c) (
       2 $CellContext`a^2 + $CellContext`b $CellContext`c) + 
      2 $CellContext`a Subscript[$CellContext`S, $CellContext`\[Omega]])],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[-$CellContext`a^2 ($CellContext`a - $CellContext`b - \
$CellContext`c) ($CellContext`b - $CellContext`c)^2 ($CellContext`a \
$CellContext`b $CellContext`c - ($CellContext`b + $CellContext`c) (
      2 $CellContext`a^2 + $CellContext`b $CellContext`c) + 
     2 $CellContext`a Subscript[$CellContext`S, $CellContext`\[Omega]])]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780258352517*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"759acb90-cf4a-4732-aac5-d9faaccff7bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      center 6-9-13: \"\>", "\[InvisibleSpace]", 
   "1.77063227783358561191763216401985244927`20."}],
  SequenceForm[
  "      center 6-9-13: ", 1.77063227783358561191763216401985244927`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802583536673`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"336bb4f4-8073-4e51-840d-372435a7460c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Persp: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"b", "-", "c"}], ")"}]}], "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Persp: ", -$CellContext`a^2 ($CellContext`a - $CellContext`b - \
$CellContext`c) ($CellContext`b - $CellContext`c), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780258354925*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"d8d2acf9-8143-440e-aca9-d45c1bda14a3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      persp  6-9-13: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "7.7271246146607229943736532787743569612`20."}]}],
  SequenceForm[
  "      persp  6-9-13: ", -7.7271246146607229943736532787743569612`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780258355891*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"faa2d193-a98e-4a83-adee-c4f8895fd51c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["1", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}]]}], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      4th: ", -$CellContext`b^(-2) $CellContext`c^(-2)/((-2) \
$CellContext`a^2 + ($CellContext`b - $CellContext`c)^2 + $CellContext`a \
($CellContext`b + $CellContext`c)), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780258356881*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"b94db49b-cbbd-4454-936c-7e21f3729e20"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"-b^2 c^2 \\\\left(-2 a^2+a \
(b+c)+(b-c)^2\\\\right)\"\>",
    TeXForm[-$CellContext`b^2 $CellContext`c^2 ((-2) $CellContext`a^2 + \
($CellContext`b - $CellContext`c)^2 + $CellContext`a ($CellContext`b + \
$CellContext`c))],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[-$CellContext`b^2 $CellContext`c^2 ((-2) $CellContext`a^2 + \
($CellContext`b - $CellContext`c)^2 + $CellContext`a ($CellContext`b + \
$CellContext`c))]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780258388459*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"445d1879-c39d-4d3f-ad0b-753bcf608872"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "6.13499894248134885467442743488928407316`20."}],
  SequenceForm[
  "      4th 6-9-13: ", 6.13499894248134885467442743488928407316`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802583896008`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"1dfcc2e9-f4ca-460c-83bb-d6f51f56a5d3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th: \"\>", "\[InvisibleSpace]", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"b", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c"}], ")"}], "2"], " ", "c"}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], "-", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "3"], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}]], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Steiner 4th: ", ($CellContext`b ($CellContext`b - $CellContext`c)^2 \
$CellContext`c + $CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2) - \
$CellContext`a ($CellContext`b^3 + $CellContext`c^3))^(-1), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780258390572*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"8518ec73-8a0b-4860-8df8-6373fc09ff69"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"a^2 \\\\left(b^2+c^2\\\\right)-a \\\\left(b^3+c^3\\\
\\right)+b c (b-c)^2\"\>",
    TeXForm[$CellContext`b ($CellContext`b - $CellContext`c)^2 $CellContext`c + \
$CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2) - $CellContext`a \
($CellContext`b^3 + $CellContext`c^3)],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[$CellContext`b ($CellContext`b - $CellContext`c)^2 $CellContext`c + \
$CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2) - $CellContext`a \
($CellContext`b^3 + $CellContext`c^3)]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802583916388`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"43c09dbc-1fa2-411e-b014-04a3df6fd3ca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "1.47629679083302279176705047092064342906`20."}],
  SequenceForm[
  "      Steiner 4th 6-9-13: ", 1.47629679083302279176705047092064342906`20.],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802583925734`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"a2fce923-9c42-49c1-9529-aa821738d6e2"],

Cell[BoxData[
 StyleBox["\<\"Conic 6-13:\"\>",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontWeight->Bold,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802584591713`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"faa95ff5-4912-461e-a4f7-3887cd1a18ca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Equation: \"\>", "\[InvisibleSpace]", 
   RowBox[{"2", " ", 
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["S", "A", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       SuperscriptBox["a", "2"], " ", "S"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SubscriptBox["S", "\[Omega]"]}]}], ")"}]}]}],
  SequenceForm[
  "      Equation: ", 
   2 $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2) ($CellContext`b^2 \
$CellContext`c^2 - 4 
    Subscript[$CellContext`S, $CellContext`A]^2) (-($CellContext`b^2 - \
$CellContext`c^2)^2 + 
    3^Rational[1, 2] $CellContext`a^2 $CellContext`S + $CellContext`a^2 
     Subscript[$CellContext`S, $CellContext`\[Omega]])],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780258460466*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"d6d44029-86fd-4dfb-9e42-15e4bce7ac1f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Center: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "10"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "8"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"]}], ")"}]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", 
          SuperscriptBox["b", "4"]}], "+", 
         RowBox[{"7", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["c", "4"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SuperscriptBox["b", "6"]}], "-", 
         RowBox[{
          SuperscriptBox["b", "4"], " ", 
          SuperscriptBox["c", "2"]}], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "4"]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["c", "6"]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "8"], "-", 
         RowBox[{"7", " ", 
          SuperscriptBox["b", "6"], " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["b", "4"], " ", 
          SuperscriptBox["c", "4"]}], "-", 
         RowBox[{"7", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "6"]}], "+", 
         SuperscriptBox["c", "8"]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox["3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "8"], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"]}], ")"}], "2"]}], "-", 
         RowBox[{
          SuperscriptBox["a", "6"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "6"], "+", 
            RowBox[{
             SuperscriptBox["b", "4"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "4"]}], "+", 
            SuperscriptBox["c", "6"]}], ")"}]}]}], ")"}], " ", "S"}]}], ")"}],
     " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["S", "A"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["S", "A"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["a", "2"], " ", "S"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SubscriptBox["S", "\[Omega]"]}]}], ")"}]}], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Center: ", -$CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 \
(-$CellContext`a^10 + 
    4 $CellContext`a^8 ($CellContext`b^2 + $CellContext`c^2) - 
    3 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^2 + $CellContext`c^2) - $CellContext`a^6 (
     6 $CellContext`b^4 + 7 $CellContext`b^2 $CellContext`c^2 + 
     6 $CellContext`c^4) + $CellContext`a^4 (
      4 $CellContext`b^6 - $CellContext`b^4 $CellContext`c^2 - \
$CellContext`b^2 $CellContext`c^4 + 
      4 $CellContext`c^6) - $CellContext`a^2 ($CellContext`b^8 - 
     7 $CellContext`b^6 $CellContext`c^2 + 
     6 $CellContext`b^4 $CellContext`c^4 - 
     7 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8) + 
    2 3^Rational[
       1, 2] ($CellContext`a^8 - $CellContext`b^2 $CellContext`c^2 \
($CellContext`b^2 - $CellContext`c^2)^2 - $CellContext`a^6 ($CellContext`b^2 + \
$CellContext`c^2) - $CellContext`a^4 ($CellContext`b^4 + $CellContext`b^2 \
$CellContext`c^2 + $CellContext`c^4) + $CellContext`a^2 ($CellContext`b^6 + \
$CellContext`b^4 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^4 + \
$CellContext`c^6)) $CellContext`S) (-$CellContext`b $CellContext`c - 2 
    Subscript[$CellContext`S, $CellContext`A]) ($CellContext`b $CellContext`c - 
    2 Subscript[$CellContext`S, $CellContext`A]) ((-2) ($CellContext`b^2 - \
$CellContext`c^2)^2 + 2 3^Rational[1, 2] $CellContext`a^2 $CellContext`S + 
    2 $CellContext`a^2 Subscript[$CellContext`S, $CellContext`\[Omega]]), 
   "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802590861998`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"511fa281-9382-4afe-9686-536d8bb4a562"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"-a^2 \\\\left(b^2-c^2\\\\right)^2 \
\\\\left(-a^{10}+4 a^8 \\\\left(b^2+c^2\\\\right)-a^6 \\\\left(6 b^4+7 b^2 \
c^2+6 c^4\\\\right)+a^4 \\\\left(4 b^6-b^4 c^2-b^2 c^4+4 c^6\\\\right)-a^2 \\\
\\left(b^8-7 b^6 c^2+6 b^4 c^4-7 b^2 c^6+c^8\\\\right)+2 \\\\sqrt{3} S \
\\\\left(a^8-a^6 \\\\left(b^2+c^2\\\\right)-a^4 \\\\left(b^4+b^2 \
c^2+c^4\\\\right)+a^2 \\\\left(b^6+b^4 c^2+b^2 c^4+c^6\\\\right)-b^2 c^2 \
\\\\left(b^2-c^2\\\\right)^2\\\\right)-3 b^2 c^2 \\\\left(b^2-c^2\\\\right)^2 \
\\\\left(b^2+c^2\\\\right)\\\\right) \\\\left(-2 S_A-b c\\\\right) \\\\left(b \
c-2 S_A\\\\right) \\\\left(2 a^2 S_{\\\\omega }+2 \\\\sqrt{3} a^2 S-2 \
\\\\left(b^2-c^2\\\\right)^2\\\\right)\"\>",
    TeXForm[-$CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 \
(-$CellContext`a^10 + 
      4 $CellContext`a^8 ($CellContext`b^2 + $CellContext`c^2) - 
      3 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^2 + $CellContext`c^2) - $CellContext`a^6 (
       6 $CellContext`b^4 + 7 $CellContext`b^2 $CellContext`c^2 + 
       6 $CellContext`c^4) + $CellContext`a^4 (
        4 $CellContext`b^6 - $CellContext`b^4 $CellContext`c^2 - \
$CellContext`b^2 $CellContext`c^4 + 
        4 $CellContext`c^6) - $CellContext`a^2 ($CellContext`b^8 - 
       7 $CellContext`b^6 $CellContext`c^2 + 
       6 $CellContext`b^4 $CellContext`c^4 - 
       7 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8) + 
      2 3^Rational[
         1, 2] ($CellContext`a^8 - $CellContext`b^2 $CellContext`c^2 \
($CellContext`b^2 - $CellContext`c^2)^2 - $CellContext`a^6 ($CellContext`b^2 + \
$CellContext`c^2) - $CellContext`a^4 ($CellContext`b^4 + $CellContext`b^2 \
$CellContext`c^2 + $CellContext`c^4) + $CellContext`a^2 ($CellContext`b^6 + \
$CellContext`b^4 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^4 + \
$CellContext`c^6)) $CellContext`S) (-$CellContext`b $CellContext`c - 2 
      Subscript[$CellContext`S, $CellContext`A]) ($CellContext`b \
$CellContext`c - 2 
      Subscript[$CellContext`S, $CellContext`A]) ((-2) ($CellContext`b^2 - \
$CellContext`c^2)^2 + 2 3^Rational[1, 2] $CellContext`a^2 $CellContext`S + 
      2 $CellContext`a^2 Subscript[$CellContext`S, $CellContext`\[Omega]])],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[-$CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 \
(-$CellContext`a^10 + 
     4 $CellContext`a^8 ($CellContext`b^2 + $CellContext`c^2) - 
     3 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^2 + $CellContext`c^2) - $CellContext`a^6 (
      6 $CellContext`b^4 + 7 $CellContext`b^2 $CellContext`c^2 + 
      6 $CellContext`c^4) + $CellContext`a^4 (
       4 $CellContext`b^6 - $CellContext`b^4 $CellContext`c^2 - \
$CellContext`b^2 $CellContext`c^4 + 
       4 $CellContext`c^6) - $CellContext`a^2 ($CellContext`b^8 - 
      7 $CellContext`b^6 $CellContext`c^2 + 
      6 $CellContext`b^4 $CellContext`c^4 - 
      7 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8) + 
     2 3^Rational[
        1, 2] ($CellContext`a^8 - $CellContext`b^2 $CellContext`c^2 \
($CellContext`b^2 - $CellContext`c^2)^2 - $CellContext`a^6 ($CellContext`b^2 + \
$CellContext`c^2) - $CellContext`a^4 ($CellContext`b^4 + $CellContext`b^2 \
$CellContext`c^2 + $CellContext`c^4) + $CellContext`a^2 ($CellContext`b^6 + \
$CellContext`b^4 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^4 + \
$CellContext`c^6)) $CellContext`S) (-$CellContext`b $CellContext`c - 2 
     Subscript[$CellContext`S, $CellContext`A]) ($CellContext`b \
$CellContext`c - 2 
     Subscript[$CellContext`S, $CellContext`A]) ((-2) ($CellContext`b^2 - \
$CellContext`c^2)^2 + 2 3^Rational[1, 2] $CellContext`a^2 $CellContext`S + 
     2 $CellContext`a^2 Subscript[$CellContext`S, $CellContext`\[Omega]])]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780259129787*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"2efe8eee-1f29-4d60-a01f-a6df9d93f186"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      center 6-9-13: \"\>", "\[InvisibleSpace]", 
   "4.48384557019149119532918664695285954225`20."}],
  SequenceForm[
  "      center 6-9-13: ", 4.48384557019149119532918664695285954225`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780259131679*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"0fd47219-cf2a-4204-9d48-2d23e946446a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Persp: \"\>", "\[InvisibleSpace]", 
   RowBox[{"2", " ", 
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"4", " ", 
       SubsuperscriptBox["S", "A", "2"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       SuperscriptBox["a", "2"], " ", "S"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SubscriptBox["S", "\[Omega]"]}]}], ")"}]}], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Persp: ", 
   2 $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2) ($CellContext`b^2 \
$CellContext`c^2 - 4 
    Subscript[$CellContext`S, $CellContext`A]^2) (-($CellContext`b^2 - \
$CellContext`c^2)^2 + 
    3^Rational[1, 2] $CellContext`a^2 $CellContext`S + $CellContext`a^2 
     Subscript[$CellContext`S, $CellContext`\[Omega]]), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802591330338`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"9b9d5c6f-bd55-4087-a642-c11a7baeff9e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      persp  6-9-13: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "3.78035056776792944354600476115524761181`20."}]}],
  SequenceForm[
  "      persp  6-9-13: ", -3.78035056776792944354600476115524761181`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802591341553`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"c6207812-cbfd-415a-9ab3-60a3470aafc3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SuperscriptBox["a", "10"]}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["a", "8"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"]}], ")"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["b", "4"]}], "-", 
             RowBox[{
              SuperscriptBox["b", "2"], " ", 
              SuperscriptBox["c", "2"]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["c", "4"]}]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["a", "6"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", 
              SuperscriptBox["b", "4"]}], "+", 
             RowBox[{"14", " ", 
              SuperscriptBox["b", "2"], " ", 
              SuperscriptBox["c", "2"]}], "+", 
             RowBox[{"5", " ", 
              SuperscriptBox["c", "4"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["a", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "6"], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["b", "4"], " ", 
              SuperscriptBox["c", "2"]}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["b", "2"], " ", 
              SuperscriptBox["c", "4"]}], "+", 
             SuperscriptBox["c", "6"]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              SuperscriptBox["b", "2"], " ", 
              SuperscriptBox["c", "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["b", "2"], "-", 
                 SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
             RowBox[{
              SuperscriptBox["a", "6"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["b", "2"], "+", 
                SuperscriptBox["c", "2"]}], ")"}]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["b", "4"], "+", 
                SuperscriptBox["c", "4"]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["b", "6"], "+", 
                SuperscriptBox["c", "6"]}], ")"}]}]}], ")"}], " ", "S"}]}], 
         ")"}]}], ")"}]}], ")"}]}], "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      4th: ", -$CellContext`b^(-2) $CellContext`c^(-2)/((-4) \
$CellContext`a^10 + 9 $CellContext`a^8 ($CellContext`b^2 + $CellContext`c^2) + 
   2 ($CellContext`b^2 - $CellContext`c^2)^4 ($CellContext`b^2 + \
$CellContext`c^2) - $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 (
    3 $CellContext`b^4 - $CellContext`b^2 $CellContext`c^2 + 
    3 $CellContext`c^4) - $CellContext`a^6 (5 $CellContext`b^4 + 
    14 $CellContext`b^2 $CellContext`c^2 + 
    5 $CellContext`c^4) + $CellContext`a^4 ($CellContext`b^6 + 
     4 $CellContext`b^4 $CellContext`c^2 + 
     4 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6) + 
   2 3^Rational[
      1, 2] ((-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 + $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2) - 
     2 $CellContext`a^4 ($CellContext`b^4 + $CellContext`c^4) + \
$CellContext`a^2 ($CellContext`b^6 + $CellContext`c^6)) $CellContext`S), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.86078025944326*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"a762b977-c691-426c-9f52-b31541e6e39b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"-b^2 c^2 \\\\left(-4 a^{10}+9 a^8 \
\\\\left(b^2+c^2\\\\right)-a^6 \\\\left(5 b^4+14 b^2 c^2+5 c^4\\\\right)+a^4 \
\\\\left(b^6+4 b^4 c^2+4 b^2 c^4+c^6\\\\right)-a^2 \
\\\\left(b^2-c^2\\\\right)^2 \\\\left(3 b^4-b^2 c^2+3 c^4\\\\right)+2 \
\\\\sqrt{3} S \\\\left(a^6 \\\\left(b^2+c^2\\\\right)-2 a^4 \
\\\\left(b^4+c^4\\\\right)+a^2 \\\\left(b^6+c^6\\\\right)-2 b^2 c^2 \
\\\\left(b^2-c^2\\\\right)^2\\\\right)+2 \\\\left(b^2-c^2\\\\right)^4 \
\\\\left(b^2+c^2\\\\right)\\\\right)\"\>",
    TeXForm[-$CellContext`b^2 $CellContext`c^2 ((-4) $CellContext`a^10 + 
      9 $CellContext`a^8 ($CellContext`b^2 + $CellContext`c^2) + 
      2 ($CellContext`b^2 - $CellContext`c^2)^4 ($CellContext`b^2 + \
$CellContext`c^2) - $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 (
       3 $CellContext`b^4 - $CellContext`b^2 $CellContext`c^2 + 
       3 $CellContext`c^4) - $CellContext`a^6 (5 $CellContext`b^4 + 
       14 $CellContext`b^2 $CellContext`c^2 + 
       5 $CellContext`c^4) + $CellContext`a^4 ($CellContext`b^6 + 
        4 $CellContext`b^4 $CellContext`c^2 + 
        4 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6) + 
      2 3^Rational[
         1, 2] ((-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 + $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2) - 
        2 $CellContext`a^4 ($CellContext`b^4 + $CellContext`c^4) + \
$CellContext`a^2 ($CellContext`b^6 + $CellContext`c^6)) $CellContext`S)],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[-$CellContext`b^2 $CellContext`c^2 ((-4) $CellContext`a^10 + 
     9 $CellContext`a^8 ($CellContext`b^2 + $CellContext`c^2) + 
     2 ($CellContext`b^2 - $CellContext`c^2)^4 ($CellContext`b^2 + \
$CellContext`c^2) - $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 (
      3 $CellContext`b^4 - $CellContext`b^2 $CellContext`c^2 + 
      3 $CellContext`c^4) - $CellContext`a^6 (5 $CellContext`b^4 + 
      14 $CellContext`b^2 $CellContext`c^2 + 
      5 $CellContext`c^4) + $CellContext`a^4 ($CellContext`b^6 + 
       4 $CellContext`b^4 $CellContext`c^2 + 
       4 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6) + 
     2 3^Rational[
        1, 2] ((-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 + $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2) - 
       2 $CellContext`a^4 ($CellContext`b^4 + $CellContext`c^4) + \
$CellContext`a^2 ($CellContext`b^6 + $CellContext`c^6)) $CellContext`S)]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780259492703*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"1c83d584-3585-48c9-b58a-7a45bfb53842"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "12.41382902489731178565591105697967197078`20."}],
  SequenceForm[
  "      4th 6-9-13: ", 12.41382902489731178565591105697967197078`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780259494163*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"38e0a7bc-bd3c-42f4-a302-f926d5ae64ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th: \"\>", "\[InvisibleSpace]", 
   RowBox[{"(", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "2"]}], " ", 
        SuperscriptBox["c", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "-", 
           SuperscriptBox["c", "2"]}], ")"}], "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "10"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["a", "6"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"]}], ")"}], "3"]}], "-", 
       RowBox[{
        SuperscriptBox["a", "8"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"5", " ", 
           SuperscriptBox["b", "4"]}], "+", 
          RowBox[{"8", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "+", 
          RowBox[{"5", " ", 
           SuperscriptBox["c", "4"]}]}], ")"}]}], "-", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "-", 
           SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "6"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "4"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "4"]}], "+", 
          SuperscriptBox["c", "6"]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["a", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "8"], "-", 
          RowBox[{"6", " ", 
           SuperscriptBox["b", "6"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{"6", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "6"]}], "+", 
          SuperscriptBox["c", "8"]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["b", "2"]}], " ", 
           SuperscriptBox["c", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["a", "6"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "4"], "+", 
             SuperscriptBox["c", "4"]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "6"], "+", 
             SuperscriptBox["c", "6"]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "8"], "+", 
             SuperscriptBox["c", "8"]}], ")"}]}]}], ")"}], " ", "S"}]}], 
      ")"}]}], ")"}], "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Steiner 4th: ", (-$CellContext`b^2 $CellContext`c^2 \
($CellContext`b^2 - $CellContext`c^2)^4 + 
    2 $CellContext`a^10 ($CellContext`b^2 + $CellContext`c^2) + 
    3 $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2)^3 - \
$CellContext`a^8 (5 $CellContext`b^4 + 8 $CellContext`b^2 $CellContext`c^2 + 
     5 $CellContext`c^4) - $CellContext`a^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^6 - 2 $CellContext`b^4 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6) + \
$CellContext`a^4 ($CellContext`b^8 - 6 $CellContext`b^6 $CellContext`c^2 - 
      6 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8) - 2 
    3^Rational[
      1, 2] (-$CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^2 + $CellContext`c^2) + $CellContext`a^6 \
($CellContext`b^4 + $CellContext`c^4) - 
     2 $CellContext`a^4 ($CellContext`b^6 + $CellContext`c^6) + \
$CellContext`a^2 ($CellContext`b^8 + $CellContext`c^8)) $CellContext`S)^(-1), 
   "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780259754181*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"fe2dc7a4-7735-42da-ba29-4b0caa971ead"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"2 a^{10} \\\\left(b^2+c^2\\\\right)-a^8 \\\\left(5 \
b^4+8 b^2 c^2+5 c^4\\\\right)+3 a^6 \\\\left(b^2+c^2\\\\right)^3+a^4 \
\\\\left(b^8-6 b^6 c^2-6 b^2 c^6+c^8\\\\right)-a^2 \
\\\\left(b^2-c^2\\\\right)^2 \\\\left(b^6-2 b^4 c^2-2 b^2 c^4+c^6\\\\right)-2 \
\\\\sqrt{3} S \\\\left(a^6 \\\\left(b^4+c^4\\\\right)-2 a^4 \
\\\\left(b^6+c^6\\\\right)+a^2 \\\\left(b^8+c^8\\\\right)-b^2 c^2 \
\\\\left(b^2-c^2\\\\right)^2 \\\\left(b^2+c^2\\\\right)\\\\right)-b^2 c^2 \
\\\\left(b^2-c^2\\\\right)^4\"\>",
    TeXForm[-$CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^4 + 
     2 $CellContext`a^10 ($CellContext`b^2 + $CellContext`c^2) + 
     3 $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2)^3 - \
$CellContext`a^8 (5 $CellContext`b^4 + 8 $CellContext`b^2 $CellContext`c^2 + 
      5 $CellContext`c^4) - $CellContext`a^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^6 - 2 $CellContext`b^4 $CellContext`c^2 - 
      2 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6) + \
$CellContext`a^4 ($CellContext`b^8 - 6 $CellContext`b^6 $CellContext`c^2 - 
       6 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8) - 2 
     3^Rational[
       1, 2] (-$CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^2 + $CellContext`c^2) + $CellContext`a^6 \
($CellContext`b^4 + $CellContext`c^4) - 
      2 $CellContext`a^4 ($CellContext`b^6 + $CellContext`c^6) + \
$CellContext`a^2 ($CellContext`b^8 + $CellContext`c^8)) $CellContext`S],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[-$CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^4 + 
    2 $CellContext`a^10 ($CellContext`b^2 + $CellContext`c^2) + 
    3 $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2)^3 - \
$CellContext`a^8 (5 $CellContext`b^4 + 8 $CellContext`b^2 $CellContext`c^2 + 
     5 $CellContext`c^4) - $CellContext`a^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^6 - 2 $CellContext`b^4 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6) + \
$CellContext`a^4 ($CellContext`b^8 - 6 $CellContext`b^6 $CellContext`c^2 - 
      6 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8) - 2 
    3^Rational[
      1, 2] (-$CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^2 + $CellContext`c^2) + $CellContext`a^6 \
($CellContext`b^4 + $CellContext`c^4) - 
     2 $CellContext`a^4 ($CellContext`b^6 + $CellContext`c^6) + \
$CellContext`a^2 ($CellContext`b^8 + $CellContext`c^8)) $CellContext`S]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780259795046*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"9333008d-7a96-41eb-aea5-6c5b4822ba79"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "7.86855887336581682531157067798902877593`20."}],
  SequenceForm[
  "      Steiner 4th 6-9-13: ", 7.86855887336581682531157067798902877593`20.],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780259796618*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"42452098-ccff-4018-8d36-dadf8df51477"],

Cell[BoxData[
 StyleBox["\<\"Conic 6-14:\"\>",
  StripOnInput->False,
  LineColor->RGBColor[1, 0, 0],
  FrontFaceColor->RGBColor[1, 0, 0],
  BackFaceColor->RGBColor[1, 0, 0],
  GraphicsColor->RGBColor[1, 0, 0],
  FontSize->18,
  FontWeight->Bold,
  FontColor->RGBColor[1, 0, 0]]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802598730097`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"4550679c-44d9-44a2-9ec5-84a777d09b58"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Equation: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"]}], ")"}], "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"], "-", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["S", "A"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["S", "A"]}]}], ")"}]}]}],
  SequenceForm[
  "      Equation: ", $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2) \
(-$CellContext`a^4 + 
    2 ($CellContext`b^2 - $CellContext`c^2)^2 - $CellContext`a^2 \
($CellContext`b^2 + $CellContext`c^2 - 2 
     3^Rational[1, 2] $CellContext`S)) (-$CellContext`b $CellContext`c - 2 
    Subscript[$CellContext`S, $CellContext`A]) ($CellContext`b $CellContext`c - 
    2 Subscript[$CellContext`S, $CellContext`A])],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780259874542*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"2e5b6749-0e61-4ae3-a16f-3b01f10398fd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Center: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "10"], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "8"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"]}], ")"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", 
          SuperscriptBox["b", "4"]}], "+", 
         RowBox[{"7", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["c", "4"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "4"}], " ", 
          SuperscriptBox["b", "6"]}], "+", 
         RowBox[{
          SuperscriptBox["b", "4"], " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "4"]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["c", "6"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "8"], "-", 
         RowBox[{"7", " ", 
          SuperscriptBox["b", "6"], " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["b", "4"], " ", 
          SuperscriptBox["c", "4"]}], "-", 
         RowBox[{"7", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "6"]}], "+", 
         SuperscriptBox["c", "8"]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox["3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "8"], "-", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"]}], ")"}], "2"]}], "-", 
         RowBox[{
          SuperscriptBox["a", "6"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "6"], "+", 
            RowBox[{
             SuperscriptBox["b", "4"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "4"]}], "+", 
            SuperscriptBox["c", "6"]}], ")"}]}]}], ")"}], " ", "S"}]}], ")"}],
     " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"]}], ")"}], "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"], "-", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["S", "A"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["S", "A"]}]}], ")"}]}], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Center: ", -$CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 \
($CellContext`a^10 - 4 $CellContext`a^8 ($CellContext`b^2 + $CellContext`c^2) + 
    3 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^2 + $CellContext`c^2) + $CellContext`a^6 (
      6 $CellContext`b^4 + 7 $CellContext`b^2 $CellContext`c^2 + 
      6 $CellContext`c^4) + $CellContext`a^4 ((-4) $CellContext`b^6 + \
$CellContext`b^4 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^4 - 
      4 $CellContext`c^6) + $CellContext`a^2 ($CellContext`b^8 - 
      7 $CellContext`b^6 $CellContext`c^2 + 
      6 $CellContext`b^4 $CellContext`c^4 - 
      7 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8) + 
    2 3^Rational[
       1, 2] ($CellContext`a^8 - $CellContext`b^2 $CellContext`c^2 \
($CellContext`b^2 - $CellContext`c^2)^2 - $CellContext`a^6 ($CellContext`b^2 + \
$CellContext`c^2) - $CellContext`a^4 ($CellContext`b^4 + $CellContext`b^2 \
$CellContext`c^2 + $CellContext`c^4) + $CellContext`a^2 ($CellContext`b^6 + \
$CellContext`b^4 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^4 + \
$CellContext`c^6)) $CellContext`S) (-$CellContext`a^4 + 
    2 ($CellContext`b^2 - $CellContext`c^2)^2 - $CellContext`a^2 \
($CellContext`b^2 + $CellContext`c^2 - 2 
     3^Rational[1, 2] $CellContext`S)) (-$CellContext`b $CellContext`c - 2 
    Subscript[$CellContext`S, $CellContext`A]) ($CellContext`b $CellContext`c - 
    2 Subscript[$CellContext`S, $CellContext`A]), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780260368465*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"97553dbd-8fa6-47f8-aeb7-d333fbe88d91"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"-a^2 \\\\left(b^2-c^2\\\\right)^2 \\\\left(a^{10}-4 \
a^8 \\\\left(b^2+c^2\\\\right)+a^6 \\\\left(6 b^4+7 b^2 c^2+6 \
c^4\\\\right)+a^4 \\\\left(-4 b^6+b^4 c^2+b^2 c^4-4 c^6\\\\right)+a^2 \
\\\\left(b^8-7 b^6 c^2+6 b^4 c^4-7 b^2 c^6+c^8\\\\right)+2 \\\\sqrt{3} S \
\\\\left(a^8-a^6 \\\\left(b^2+c^2\\\\right)-a^4 \\\\left(b^4+b^2 \
c^2+c^4\\\\right)+a^2 \\\\left(b^6+b^4 c^2+b^2 c^4+c^6\\\\right)-b^2 c^2 \
\\\\left(b^2-c^2\\\\right)^2\\\\right)+3 b^2 c^2 \\\\left(b^2-c^2\\\\right)^2 \
\\\\left(b^2+c^2\\\\right)\\\\right) \\\\left(-a^4-a^2 \\\\left(b^2+c^2-2 \
\\\\sqrt{3} S\\\\right)+2 \\\\left(b^2-c^2\\\\right)^2\\\\right) \\\\left(-2 \
S_A-b c\\\\right) \\\\left(b c-2 S_A\\\\right)\"\>",
    TeXForm[-$CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 \
($CellContext`a^10 - 4 $CellContext`a^8 ($CellContext`b^2 + $CellContext`c^2) + 
      3 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^2 + $CellContext`c^2) + $CellContext`a^6 (
        6 $CellContext`b^4 + 7 $CellContext`b^2 $CellContext`c^2 + 
        6 $CellContext`c^4) + $CellContext`a^4 ((-4) $CellContext`b^6 + \
$CellContext`b^4 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^4 - 
        4 $CellContext`c^6) + $CellContext`a^2 ($CellContext`b^8 - 
        7 $CellContext`b^6 $CellContext`c^2 + 
        6 $CellContext`b^4 $CellContext`c^4 - 
        7 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8) + 
      2 3^Rational[
         1, 2] ($CellContext`a^8 - $CellContext`b^2 $CellContext`c^2 \
($CellContext`b^2 - $CellContext`c^2)^2 - $CellContext`a^6 ($CellContext`b^2 + \
$CellContext`c^2) - $CellContext`a^4 ($CellContext`b^4 + $CellContext`b^2 \
$CellContext`c^2 + $CellContext`c^4) + $CellContext`a^2 ($CellContext`b^6 + \
$CellContext`b^4 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^4 + \
$CellContext`c^6)) $CellContext`S) (-$CellContext`a^4 + 
      2 ($CellContext`b^2 - $CellContext`c^2)^2 - $CellContext`a^2 \
($CellContext`b^2 + $CellContext`c^2 - 2 
       3^Rational[1, 2] $CellContext`S)) (-$CellContext`b $CellContext`c - 2 
      Subscript[$CellContext`S, $CellContext`A]) ($CellContext`b \
$CellContext`c - 2 Subscript[$CellContext`S, $CellContext`A])],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[-$CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 \
($CellContext`a^10 - 4 $CellContext`a^8 ($CellContext`b^2 + $CellContext`c^2) + 
     3 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^2 + $CellContext`c^2) + $CellContext`a^6 (
       6 $CellContext`b^4 + 7 $CellContext`b^2 $CellContext`c^2 + 
       6 $CellContext`c^4) + $CellContext`a^4 ((-4) $CellContext`b^6 + \
$CellContext`b^4 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^4 - 
       4 $CellContext`c^6) + $CellContext`a^2 ($CellContext`b^8 - 
       7 $CellContext`b^6 $CellContext`c^2 + 
       6 $CellContext`b^4 $CellContext`c^4 - 
       7 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8) + 
     2 3^Rational[
        1, 2] ($CellContext`a^8 - $CellContext`b^2 $CellContext`c^2 \
($CellContext`b^2 - $CellContext`c^2)^2 - $CellContext`a^6 ($CellContext`b^2 + \
$CellContext`c^2) - $CellContext`a^4 ($CellContext`b^4 + $CellContext`b^2 \
$CellContext`c^2 + $CellContext`c^4) + $CellContext`a^2 ($CellContext`b^6 + \
$CellContext`b^4 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^4 + \
$CellContext`c^6)) $CellContext`S) (-$CellContext`a^4 + 
     2 ($CellContext`b^2 - $CellContext`c^2)^2 - $CellContext`a^2 \
($CellContext`b^2 + $CellContext`c^2 - 2 
      3^Rational[1, 2] $CellContext`S)) (-$CellContext`b $CellContext`c - 2 
     Subscript[$CellContext`S, $CellContext`A]) ($CellContext`b \
$CellContext`c - 2 Subscript[$CellContext`S, $CellContext`A])]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780260410932*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"f51cc654-7dcb-4256-8aab-44031e52f48c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      center 6-9-13: \"\>", "\[InvisibleSpace]", 
   "2.38756143849493654344978421023783943027`20."}],
  SequenceForm[
  "      center 6-9-13: ", 2.38756143849493654344978421023783943027`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802604167128`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"89dc80a4-c57d-48b8-bfc1-4566ee5fa4bb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Persp: \"\>", "\[InvisibleSpace]", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"]}], ")"}], "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"], "-", 
         RowBox[{"2", " ", 
          SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "b"}], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["S", "A"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"b", " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SubscriptBox["S", "A"]}]}], ")"}]}], 
   "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Persp: ", $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2) \
(-$CellContext`a^4 + 
    2 ($CellContext`b^2 - $CellContext`c^2)^2 - $CellContext`a^2 \
($CellContext`b^2 + $CellContext`c^2 - 2 
     3^Rational[1, 2] $CellContext`S)) (-$CellContext`b $CellContext`c - 2 
    Subscript[$CellContext`S, $CellContext`A]) ($CellContext`b $CellContext`c - 
    2 Subscript[$CellContext`S, $CellContext`A]), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802604502087`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"fe618ae8-2307-44c3-9cce-8e95f00982a9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      persp  6-9-13: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "6.37336230307572235081516419639209406814`20."}]}],
  SequenceForm[
  "      persp  6-9-13: ", -6.37336230307572235081516419639209406814`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780260451612*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"38e7e901-9dfd-42ed-8f69-76423cfce1a9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["c", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           SuperscriptBox["a", "10"]}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["a", "8"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"]}], ")"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              SuperscriptBox["b", "4"]}], "-", 
             RowBox[{
              SuperscriptBox["b", "2"], " ", 
              SuperscriptBox["c", "2"]}], "+", 
             RowBox[{"3", " ", 
              SuperscriptBox["c", "4"]}]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["a", "6"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", 
              SuperscriptBox["b", "4"]}], "+", 
             RowBox[{"14", " ", 
              SuperscriptBox["b", "2"], " ", 
              SuperscriptBox["c", "2"]}], "+", 
             RowBox[{"5", " ", 
              SuperscriptBox["c", "4"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["a", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "6"], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["b", "4"], " ", 
              SuperscriptBox["c", "2"]}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox["b", "2"], " ", 
              SuperscriptBox["c", "4"]}], "+", 
             SuperscriptBox["c", "6"]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              SuperscriptBox["b", "2"], " ", 
              SuperscriptBox["c", "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["b", "2"], "-", 
                 SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
             RowBox[{
              SuperscriptBox["a", "6"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["b", "2"], "+", 
                SuperscriptBox["c", "2"]}], ")"}]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox["a", "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["b", "4"], "+", 
                SuperscriptBox["c", "4"]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["a", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["b", "6"], "+", 
                SuperscriptBox["c", "6"]}], ")"}]}]}], ")"}], " ", "S"}]}], 
         ")"}]}], ")"}]}], ")"}]}], "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      4th: ", -$CellContext`b^(-2) $CellContext`c^(-2)/((-4) \
$CellContext`a^10 + 9 $CellContext`a^8 ($CellContext`b^2 + $CellContext`c^2) + 
   2 ($CellContext`b^2 - $CellContext`c^2)^4 ($CellContext`b^2 + \
$CellContext`c^2) - $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 (
    3 $CellContext`b^4 - $CellContext`b^2 $CellContext`c^2 + 
    3 $CellContext`c^4) - $CellContext`a^6 (5 $CellContext`b^4 + 
    14 $CellContext`b^2 $CellContext`c^2 + 
    5 $CellContext`c^4) + $CellContext`a^4 ($CellContext`b^6 + 
     4 $CellContext`b^4 $CellContext`c^2 + 
     4 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6) - 2 
   3^Rational[
     1, 2] ((-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 + $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2) - 
    2 $CellContext`a^4 ($CellContext`b^4 + $CellContext`c^4) + \
$CellContext`a^2 ($CellContext`b^6 + $CellContext`c^6)) $CellContext`S), "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780260685309*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"3645c3d1-6fbe-4971-a6a7-35e0e5d81ed9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"-b^2 c^2 \\\\left(-4 a^{10}+9 a^8 \
\\\\left(b^2+c^2\\\\right)-a^6 \\\\left(5 b^4+14 b^2 c^2+5 c^4\\\\right)+a^4 \
\\\\left(b^6+4 b^4 c^2+4 b^2 c^4+c^6\\\\right)-a^2 \
\\\\left(b^2-c^2\\\\right)^2 \\\\left(3 b^4-b^2 c^2+3 c^4\\\\right)-2 \
\\\\sqrt{3} S \\\\left(a^6 \\\\left(b^2+c^2\\\\right)-2 a^4 \
\\\\left(b^4+c^4\\\\right)+a^2 \\\\left(b^6+c^6\\\\right)-2 b^2 c^2 \
\\\\left(b^2-c^2\\\\right)^2\\\\right)+2 \\\\left(b^2-c^2\\\\right)^4 \
\\\\left(b^2+c^2\\\\right)\\\\right)\"\>",
    TeXForm[-$CellContext`b^2 $CellContext`c^2 ((-4) $CellContext`a^10 + 
      9 $CellContext`a^8 ($CellContext`b^2 + $CellContext`c^2) + 
      2 ($CellContext`b^2 - $CellContext`c^2)^4 ($CellContext`b^2 + \
$CellContext`c^2) - $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 (
       3 $CellContext`b^4 - $CellContext`b^2 $CellContext`c^2 + 
       3 $CellContext`c^4) - $CellContext`a^6 (5 $CellContext`b^4 + 
       14 $CellContext`b^2 $CellContext`c^2 + 
       5 $CellContext`c^4) + $CellContext`a^4 ($CellContext`b^6 + 
        4 $CellContext`b^4 $CellContext`c^2 + 
        4 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6) - 2 
      3^Rational[
        1, 2] ((-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 + $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2) - 
       2 $CellContext`a^4 ($CellContext`b^4 + $CellContext`c^4) + \
$CellContext`a^2 ($CellContext`b^6 + $CellContext`c^6)) $CellContext`S)],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[-$CellContext`b^2 $CellContext`c^2 ((-4) $CellContext`a^10 + 
     9 $CellContext`a^8 ($CellContext`b^2 + $CellContext`c^2) + 
     2 ($CellContext`b^2 - $CellContext`c^2)^4 ($CellContext`b^2 + \
$CellContext`c^2) - $CellContext`a^2 ($CellContext`b^2 - $CellContext`c^2)^2 (
      3 $CellContext`b^4 - $CellContext`b^2 $CellContext`c^2 + 
      3 $CellContext`c^4) - $CellContext`a^6 (5 $CellContext`b^4 + 
      14 $CellContext`b^2 $CellContext`c^2 + 
      5 $CellContext`c^4) + $CellContext`a^4 ($CellContext`b^6 + 
       4 $CellContext`b^4 $CellContext`c^2 + 
       4 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6) - 2 
     3^Rational[
       1, 2] ((-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 + $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2) - 
      2 $CellContext`a^4 ($CellContext`b^4 + $CellContext`c^4) + \
$CellContext`a^2 ($CellContext`b^6 + $CellContext`c^6)) $CellContext`S)]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780260746253*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"5582050a-c6c2-4701-9a72-7dc1c4d4550c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "8.58068775161637957816308901030340865597`20."}],
  SequenceForm[
  "      4th 6-9-13: ", 8.58068775161637957816308901030340865597`20.],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780260747755*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"1202ac61-b8dd-4709-a962-0e9aa3816d74"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th: \"\>", "\[InvisibleSpace]", 
   RowBox[{"(", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "2"]}], " ", 
        SuperscriptBox["c", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "-", 
           SuperscriptBox["c", "2"]}], ")"}], "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "10"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["a", "6"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"]}], ")"}], "3"]}], "-", 
       RowBox[{
        SuperscriptBox["a", "8"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"5", " ", 
           SuperscriptBox["b", "4"]}], "+", 
          RowBox[{"8", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "+", 
          RowBox[{"5", " ", 
           SuperscriptBox["c", "4"]}]}], ")"}]}], "-", 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "-", 
           SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "6"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "4"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "4"]}], "+", 
          SuperscriptBox["c", "6"]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["a", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "8"], "-", 
          RowBox[{"6", " ", 
           SuperscriptBox["b", "6"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{"6", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "6"]}], "+", 
          SuperscriptBox["c", "8"]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["b", "2"]}], " ", 
           SuperscriptBox["c", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["a", "6"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "4"], "+", 
             SuperscriptBox["c", "4"]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "6"], "+", 
             SuperscriptBox["c", "6"]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "8"], "+", 
             SuperscriptBox["c", "8"]}], ")"}]}]}], ")"}], " ", "S"}]}], 
      ")"}]}], ")"}], "\[InvisibleSpace]", "\<\"::\"\>"}],
  SequenceForm[
  "      Steiner 4th: ", (-$CellContext`b^2 $CellContext`c^2 \
($CellContext`b^2 - $CellContext`c^2)^4 + 
    2 $CellContext`a^10 ($CellContext`b^2 + $CellContext`c^2) + 
    3 $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2)^3 - \
$CellContext`a^8 (5 $CellContext`b^4 + 8 $CellContext`b^2 $CellContext`c^2 + 
     5 $CellContext`c^4) - $CellContext`a^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^6 - 2 $CellContext`b^4 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6) + \
$CellContext`a^4 ($CellContext`b^8 - 6 $CellContext`b^6 $CellContext`c^2 - 
      6 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8) + 
    2 3^Rational[
       1, 2] (-$CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^2 + $CellContext`c^2) + $CellContext`a^6 \
($CellContext`b^4 + $CellContext`c^4) - 
      2 $CellContext`a^4 ($CellContext`b^6 + $CellContext`c^6) + \
$CellContext`a^2 ($CellContext`b^8 + $CellContext`c^8)) $CellContext`S)^(-1), 
   "::"],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780260969344*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"2ac40bcb-d36c-4239-b35b-dc969ce83c54"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"TeX=\"\>", "\[InvisibleSpace]", 
   InterpretationBox["\<\"2 a^{10} \\\\left(b^2+c^2\\\\right)-a^8 \\\\left(5 \
b^4+8 b^2 c^2+5 c^4\\\\right)+3 a^6 \\\\left(b^2+c^2\\\\right)^3+a^4 \
\\\\left(b^8-6 b^6 c^2-6 b^2 c^6+c^8\\\\right)-a^2 \
\\\\left(b^2-c^2\\\\right)^2 \\\\left(b^6-2 b^4 c^2-2 b^2 c^4+c^6\\\\right)+2 \
\\\\sqrt{3} S \\\\left(a^6 \\\\left(b^4+c^4\\\\right)-2 a^4 \
\\\\left(b^6+c^6\\\\right)+a^2 \\\\left(b^8+c^8\\\\right)-b^2 c^2 \
\\\\left(b^2-c^2\\\\right)^2 \\\\left(b^2+c^2\\\\right)\\\\right)-b^2 c^2 \
\\\\left(b^2-c^2\\\\right)^4\"\>",
    TeXForm[-$CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^4 + 
     2 $CellContext`a^10 ($CellContext`b^2 + $CellContext`c^2) + 
     3 $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2)^3 - \
$CellContext`a^8 (5 $CellContext`b^4 + 8 $CellContext`b^2 $CellContext`c^2 + 
      5 $CellContext`c^4) - $CellContext`a^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^6 - 2 $CellContext`b^4 $CellContext`c^2 - 
      2 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6) + \
$CellContext`a^4 ($CellContext`b^8 - 6 $CellContext`b^6 $CellContext`c^2 - 
       6 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8) + 
     2 3^Rational[
        1, 2] (-$CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^2 + $CellContext`c^2) + $CellContext`a^6 \
($CellContext`b^4 + $CellContext`c^4) - 
       2 $CellContext`a^4 ($CellContext`b^6 + $CellContext`c^6) + \
$CellContext`a^2 ($CellContext`b^8 + $CellContext`c^8)) $CellContext`S],
    AutoDelete->True,
    Editable->True]}],
  SequenceForm["TeX=", 
   TeXForm[-$CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^4 + 
    2 $CellContext`a^10 ($CellContext`b^2 + $CellContext`c^2) + 
    3 $CellContext`a^6 ($CellContext`b^2 + $CellContext`c^2)^3 - \
$CellContext`a^8 (5 $CellContext`b^4 + 8 $CellContext`b^2 $CellContext`c^2 + 
     5 $CellContext`c^4) - $CellContext`a^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^6 - 2 $CellContext`b^4 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6) + \
$CellContext`a^4 ($CellContext`b^8 - 6 $CellContext`b^6 $CellContext`c^2 - 
      6 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8) + 
    2 3^Rational[
       1, 2] (-$CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2 ($CellContext`b^2 + $CellContext`c^2) + $CellContext`a^6 \
($CellContext`b^4 + $CellContext`c^4) - 
      2 $CellContext`a^4 ($CellContext`b^6 + $CellContext`c^6) + \
$CellContext`a^2 ($CellContext`b^8 + $CellContext`c^8)) $CellContext`S]],
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.860780261029283*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"84767e14-f092-4e54-b9d0-9f0e66bb31d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      Steiner 4th 6-9-13: \"\>", "\[InvisibleSpace]", 
   "2.98811911866767778310496300018724535916`20."}],
  SequenceForm[
  "      Steiner 4th 6-9-13: ", 2.98811911866767778310496300018724535916`20.],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.848746728318945*^9, 3.8607802610308037`*^9},
 CellLabel->
  "During evaluation of \
In[15]:=",ExpressionUUID->"79359133-0037-4653-8c86-835bcfc0b850"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Summary", "Chapter",
 Evaluatable->False,
 CellChangeTimes->{{3.848655957255249*^9, 3.848655989037887*^9}, {
  3.848656127231782*^9, 3.848656156450227*^9}, {3.848656272943198*^9, 
  3.848656333638954*^9}, {3.848656704568725*^9, 
  3.848656706184367*^9}},ExpressionUUID->"e5b9fe57-a757-4135-a781-\
43383de4cc71"],

Cell[TextData[StyleBox["conic  center          4th point        perspector    \
     Steiner 4th point\n1-4:   2.643 = X11.    10.962 = X104    -18.029 = \
X650      3.015 = X2481\n1-10:  1.157 = X244.    4.495 = X759    -49.582 = \
X661     -0.252 = X18827\n2-4:   2.224 = X115.   10.125 = X98       2.244 = \
X523      1.820 = X671\n2-15:  4.006 = X18334. 14.192 = X842   -137.215 = \
X526      5.382 = X?\n3-4:   3.490 = X125.   12.657 = X74      -5.076 = X647  \
    5.597 = X290\n3-15:  3.425 = X?      13.556 = X?      -24.956 = X?        \
4.553 = X?\n3-16:  3.314 = X?      14.053 = X?       14.803 = X?        3.320 \
= X?\n6-9:   1.770 = X38991.  6.134 = X2291    -7.727 = X663      1.476 = X?\n\
6-13:  4.483 = X38994. 12.413 = X2379    -3.780 = X6138     8.868 = X?\n6-14: \
 2.387 = X38993.  8.580 = X2378    -6.373 = X6137     2.988 = X?",
 FontFamily->"Courier",
 FontWeight->"Regular"]], "Text",
 CellChangeTimes->{{3.848087871517847*^9, 3.848087883828184*^9}, {
   3.848087930885056*^9, 3.848087947476562*^9}, {3.848088020901181*^9, 
   3.848088049429051*^9}, {3.8480880952613163`*^9, 3.8480881440371847`*^9}, {
   3.848089254576981*^9, 3.8480892586968184`*^9}, {3.8480893532012453`*^9, 
   3.8480893546568604`*^9}, {3.848143775488001*^9, 3.848143810990097*^9}, {
   3.8481438573186483`*^9, 3.848143871766252*^9}, {3.848143961414714*^9, 
   3.848143962798654*^9}, {3.848144162831637*^9, 3.848144164703415*^9}, {
   3.8481442831933393`*^9, 3.848144324937004*^9}, {3.848144552513998*^9, 
   3.8481445752581367`*^9}, 3.848144741162615*^9, {3.848145258444935*^9, 
   3.8481452593963737`*^9}, {3.848154037867568*^9, 3.8481540891878023`*^9}, {
   3.8481541191962223`*^9, 3.848154130876128*^9}, {3.8481542384609632`*^9, 
   3.848154298068864*^9}, {3.848154333349533*^9, 3.84815434280507*^9}, {
   3.8481543874217463`*^9, 3.8481543877892303`*^9}, {3.8481547123272657`*^9, 
   3.84815473771082*^9}, {3.8481547838793583`*^9, 3.848154840783251*^9}, {
   3.848154871415811*^9, 3.84815487184195*^9}, {3.848154915887714*^9, 
   3.8481549169196978`*^9}, {3.848167693693981*^9, 3.8481677049417467`*^9}, {
   3.848167747406118*^9, 3.8481677535417423`*^9}, {3.8481678353024673`*^9, 
   3.84816783610201*^9}, {3.84821954475348*^9, 3.8482195484415503`*^9}, {
   3.848219636329368*^9, 3.8482196613167143`*^9}, {3.8482197054240503`*^9, 
   3.84821979697783*^9}, {3.848219836658897*^9, 3.848219867226121*^9}, {
   3.848219994569847*^9, 3.8482200368734426`*^9}, {3.848220154778159*^9, 
   3.848220179346129*^9}, {3.8482203487550573`*^9, 3.848220384138472*^9}, {
   3.8482204185630417`*^9, 3.848220503762597*^9}, {3.848220558539707*^9, 
   3.848220561938953*^9}, 3.8482208497164516`*^9, {3.848220909148367*^9, 
   3.848220972028553*^9}, {3.848221038980694*^9, 3.848221059364496*^9}, {
   3.848221092860919*^9, 3.848221132829134*^9}, {3.8482211808292627`*^9, 
   3.8482211928128557`*^9}, {3.848221233829541*^9, 3.848221259213176*^9}, 
   3.848221296253487*^9, {3.848221332741749*^9, 3.8482213488053093`*^9}, {
   3.848221392629863*^9, 3.8482214080613823`*^9}, {3.848221451486145*^9, 
   3.848221452925612*^9}, {3.848221514678458*^9, 3.8482215259978313`*^9}, {
   3.84822156843064*^9, 3.848221585574057*^9}, {3.848221621622696*^9, 
   3.848221623093965*^9}, {3.8482224447935658`*^9, 3.8482224531130743`*^9}, {
   3.8482224838330708`*^9, 3.848222486928743*^9}, {3.848223919397023*^9, 
   3.848223921764596*^9}, {3.848651733142771*^9, 3.848651733807481*^9}, {
   3.848656408807949*^9, 3.8486564320394983`*^9}, {3.8486564625279713`*^9, 
   3.848656478815702*^9}, {3.8486565189764957`*^9, 
   3.84865667622456*^9}},ExpressionUUID->"309af718-545d-49e4-aea9-\
8b9303f1024a"]
}, Closed]]
},
WindowSize->{984, 1068},
WindowMargins->{{666, Automatic}, {Automatic, 129}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 973, 18, 196, "Text",ExpressionUUID->"6e334438-a89a-48db-835f-405d667141bd",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1556, 42, 244, 4, 69, "Chapter",ExpressionUUID->"8c6d2d97-d697-48c7-a27d-981caef5698c",
 Evaluatable->False],
Cell[1803, 48, 23363, 661, 773, "Input",ExpressionUUID->"c0e20cae-c86d-4901-b9d8-dd966f7cb7f1"]
}, Closed]],
Cell[CellGroupData[{
Cell[25203, 714, 220, 5, 58, "Chapter",ExpressionUUID->"41107464-cf9b-470f-a1df-e90f63cc77b8",
 Evaluatable->False],
Cell[25426, 721, 10581, 292, 1015, "Input",ExpressionUUID->"68c74ca1-8553-439a-9bb5-5bb82e6a9d4c"]
}, Closed]],
Cell[CellGroupData[{
Cell[36044, 1018, 284, 5, 58, "Chapter",ExpressionUUID->"456ec704-8b01-48a2-80e0-3ef9c52904ff",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[36353, 1027, 4831, 85, 325, "Input",ExpressionUUID->"ae12587e-cdb4-4d5e-b902-301e30965b29"],
Cell[CellGroupData[{
Cell[41209, 1116, 1103, 21, 24, "Print",ExpressionUUID->"6d5f6787-16bd-4bd2-abaf-f46afdb219e6"],
Cell[42315, 1139, 1105, 21, 24, "Print",ExpressionUUID->"0207fe42-a55d-446d-89df-c68973ee2302"],
Cell[43423, 1162, 1105, 21, 24, "Print",ExpressionUUID->"98ee7c3f-73d7-40c3-a7b1-39a527e52736"],
Cell[44531, 1185, 1103, 21, 24, "Print",ExpressionUUID->"2895178c-b10f-4756-9c21-ed857d812a7c"],
Cell[45637, 1208, 1103, 21, 24, "Print",ExpressionUUID->"4a610b8a-1631-4050-9a89-01d9e1cc4aec"],
Cell[46743, 1231, 1105, 21, 24, "Print",ExpressionUUID->"0844de95-fca7-46d2-917a-529ae67e86dd"],
Cell[47851, 1254, 1107, 21, 24, "Print",ExpressionUUID->"bce2154a-1327-4737-9634-bb93ae40efb4"],
Cell[48961, 1277, 1104, 21, 24, "Print",ExpressionUUID->"396fd63c-5959-4704-b5c2-8bf815e16a85"],
Cell[50068, 1300, 1107, 21, 24, "Print",ExpressionUUID->"a0f6a96e-0ab9-4037-a1db-96bc8f464f10"],
Cell[51178, 1323, 1105, 21, 24, "Print",ExpressionUUID->"5c1ae25d-edd9-467b-8c53-fb8d052c8303"],
Cell[52286, 1346, 1105, 21, 24, "Print",ExpressionUUID->"0a140c48-225d-487c-9869-6ef5f653136a"],
Cell[53394, 1369, 1105, 21, 24, "Print",ExpressionUUID->"c3283fa0-804b-4b79-97bf-f3218ba49721"],
Cell[54502, 1392, 1109, 21, 24, "Print",ExpressionUUID->"8b8563e4-a80a-4035-9510-858d2d012394"],
Cell[55614, 1415, 1109, 21, 24, "Print",ExpressionUUID->"9d035a53-f51b-4dcd-85df-48437e966255"],
Cell[56726, 1438, 1109, 21, 24, "Print",ExpressionUUID->"035dbdd3-5b19-4819-9af3-36aaf21d55e5"],
Cell[57838, 1461, 1107, 21, 24, "Print",ExpressionUUID->"e81d7adb-e11c-4f26-bacd-052095cd8b96"],
Cell[58948, 1484, 1107, 21, 24, "Print",ExpressionUUID->"5bb16ec0-e3f9-46ce-8869-0be8234808ff"],
Cell[60058, 1507, 1107, 21, 24, "Print",ExpressionUUID->"13ca8fbf-053b-4dfd-9ae8-237d138d7f36"],
Cell[61168, 1530, 1107, 21, 24, "Print",ExpressionUUID->"857590c7-104a-4aa6-a90a-c29551bccc79"],
Cell[62278, 1553, 1107, 21, 24, "Print",ExpressionUUID->"f49c7ebf-fdb1-4964-9aad-b8c83c10c2dd"],
Cell[63388, 1576, 1107, 21, 24, "Print",ExpressionUUID->"989e8f50-02a4-46d0-b8c4-85ea97ec7da1"],
Cell[64498, 1599, 1107, 21, 24, "Print",ExpressionUUID->"193a33df-c67c-4af3-9a24-7b07ef86d41d"],
Cell[65608, 1622, 1107, 21, 24, "Print",ExpressionUUID->"f667312e-e734-4b72-b727-f034c05f88ab"],
Cell[66718, 1645, 1102, 21, 24, "Print",ExpressionUUID->"dedc5773-ef6b-4a83-b376-136f9cdb3ab7"],
Cell[67823, 1668, 1107, 21, 24, "Print",ExpressionUUID->"57cc897a-d8dd-4549-9622-62859e840957"],
Cell[68933, 1691, 1107, 21, 24, "Print",ExpressionUUID->"45c16e98-9dcd-4af5-bc1f-7e05502dcd15"],
Cell[70043, 1714, 1103, 21, 24, "Print",ExpressionUUID->"55844180-c51a-4982-bd13-27ea958ed6d3"],
Cell[71149, 1737, 1103, 21, 24, "Print",ExpressionUUID->"d5bcabb6-afc4-4131-833e-10fca0550ef9"],
Cell[72255, 1760, 1103, 21, 24, "Print",ExpressionUUID->"13b07777-5d97-4c8d-8daf-970378acbc74"],
Cell[73361, 1783, 1107, 21, 24, "Print",ExpressionUUID->"f29d71c6-0864-40b3-ba47-bc2bafa67e5f"],
Cell[74471, 1806, 1109, 21, 24, "Print",ExpressionUUID->"be0ee609-74ad-4f80-b59a-eeaf4e11b2e9"],
Cell[75583, 1829, 1107, 21, 24, "Print",ExpressionUUID->"72e562c9-e881-48fe-ade4-d44ab181b1e8"],
Cell[76693, 1852, 1106, 21, 24, "Print",ExpressionUUID->"1932bfb8-0d13-4cf0-bad8-1b45249b7ed1"],
Cell[77802, 1875, 1107, 21, 24, "Print",ExpressionUUID->"6ad10d39-fd14-4a03-aa24-a2f778a33cca"],
Cell[78912, 1898, 1107, 21, 24, "Print",ExpressionUUID->"6d1109e1-017f-4e59-bf5c-c6ed174490a0"],
Cell[80022, 1921, 1107, 21, 24, "Print",ExpressionUUID->"16073084-f8d4-44b5-b07e-dd4a146ff74e"],
Cell[81132, 1944, 1109, 21, 24, "Print",ExpressionUUID->"0fe8625d-d02d-4c8f-b776-57a0c1446997"],
Cell[82244, 1967, 1107, 21, 24, "Print",ExpressionUUID->"7fd550eb-6b3f-41c2-b0bb-1d37f82fd2eb"],
Cell[83354, 1990, 1107, 21, 24, "Print",ExpressionUUID->"459a14c2-567f-401a-bd07-d125a8fa74d6"],
Cell[84464, 2013, 1105, 21, 24, "Print",ExpressionUUID->"2de74566-ca4b-42d5-888e-ee6fb90295c7"],
Cell[85572, 2036, 1109, 21, 24, "Print",ExpressionUUID->"894de550-5d83-4939-86b8-28d8683b0a0a"],
Cell[86684, 2059, 1109, 21, 24, "Print",ExpressionUUID->"1686bc5e-6378-429f-9f7b-a6ab7b6b7fcd"],
Cell[87796, 2082, 1105, 21, 24, "Print",ExpressionUUID->"be0fba6a-fed4-425e-a7c5-b73e2f23d4b9"],
Cell[88904, 2105, 1109, 21, 24, "Print",ExpressionUUID->"eb520553-6373-4b9b-b366-60d398642490"],
Cell[90016, 2128, 1109, 21, 24, "Print",ExpressionUUID->"3fa1a77c-0bb8-4678-9821-17afcba49b8b"],
Cell[91128, 2151, 1111, 21, 24, "Print",ExpressionUUID->"2280fbd6-5585-4196-a052-f9018876a663"],
Cell[92242, 2174, 1109, 21, 24, "Print",ExpressionUUID->"01a3ea61-0238-4f2e-a71e-aea955630ec7"],
Cell[93354, 2197, 1109, 21, 24, "Print",ExpressionUUID->"34a5404a-2307-44d6-8c52-897cf88bd668"],
Cell[94466, 2220, 1109, 21, 24, "Print",ExpressionUUID->"d8f90dc3-299a-435d-ae9c-8cf1e20cebe9"],
Cell[95578, 2243, 1109, 21, 24, "Print",ExpressionUUID->"63a91843-7c64-4ebf-b4e0-06942a50b08c"],
Cell[96690, 2266, 1109, 21, 24, "Print",ExpressionUUID->"6f6dae61-3397-499c-972f-337077bbe76f"],
Cell[97802, 2289, 1111, 21, 24, "Print",ExpressionUUID->"9d9d15e4-0f9a-486e-b243-2c58fc62526e"],
Cell[98916, 2312, 1109, 21, 24, "Print",ExpressionUUID->"90707040-27a4-46a6-9af5-f4f70107ff0d"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[100086, 2340, 304, 5, 58, "Chapter",ExpressionUUID->"1e6baa0c-c21e-4dfc-874b-bd5d4473ce88",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[100415, 2349, 22469, 576, 2201, "Input",ExpressionUUID->"0d8d7706-d4b0-4ce1-94d3-7f038669e3d1"],
Cell[CellGroupData[{
Cell[122909, 2929, 457, 13, 32, "Print",ExpressionUUID->"d8a5e8c4-6012-48c7-8ba4-9b8517690fda"],
Cell[123369, 2944, 585, 15, 24, "Print",ExpressionUUID->"2d82e00c-4db8-456a-8e3c-47bff39353b4"],
Cell[123957, 2961, 723, 18, 25, "Print",ExpressionUUID->"c045066e-696b-4142-ada2-fdbc8c46a349"],
Cell[124683, 2981, 714, 17, 24, "Print",ExpressionUUID->"33f7a78c-323e-4371-a418-f0f5cbda9cb9"],
Cell[125400, 3000, 440, 10, 24, "Print",ExpressionUUID->"50dca7f9-b635-416f-be4c-9a1646b1fe39"],
Cell[125843, 3012, 620, 15, 24, "Print",ExpressionUUID->"42396b8b-3067-4943-93cc-fe959b594d57"],
Cell[126466, 3029, 458, 10, 24, "Print",ExpressionUUID->"db503aac-d095-4ecb-a58b-9b708242dab4"],
Cell[126927, 3041, 1058, 28, 46, "Print",ExpressionUUID->"3e30ea19-8657-42f8-a565-34e885730680"],
Cell[127988, 3071, 898, 20, 24, "Print",ExpressionUUID->"502e66a9-879b-4e99-8923-479b2fd20cce"],
Cell[128889, 3093, 436, 10, 24, "Print",ExpressionUUID->"25b3a146-0637-4d54-9cf7-a302b8fc8c88"],
Cell[129328, 3105, 755, 20, 46, "Print",ExpressionUUID->"e8f73d09-982a-4769-b77e-c62bf07dee2f"],
Cell[130086, 3127, 659, 15, 24, "Print",ExpressionUUID->"e45452b0-6996-48b0-9d7a-a677573c6800"],
Cell[130748, 3144, 448, 10, 24, "Print",ExpressionUUID->"06cbae8f-0294-4b5e-9ae5-8df7d04c6e05"],
Cell[131199, 3156, 458, 13, 32, "Print",ExpressionUUID->"3d306913-0c46-4ae7-88ef-ac629f367859"],
Cell[131660, 3171, 546, 15, 27, "Print",ExpressionUUID->"d4d91e1c-511b-4242-a54d-d26b29c3152d"],
Cell[132209, 3188, 838, 22, 25, "Print",ExpressionUUID->"872c8b2c-1df9-44bf-9d65-6a3d8e569379"],
Cell[133050, 3212, 754, 17, 24, "Print",ExpressionUUID->"8b683597-c63a-4de4-a1ab-3e429e8452bd"],
Cell[133807, 3231, 440, 10, 24, "Print",ExpressionUUID->"f215fe54-971d-4208-bfe0-a03484f2c0d3"],
Cell[134250, 3243, 587, 16, 27, "Print",ExpressionUUID->"e9d58275-98c8-4e4a-8c36-f3520f468f7c"],
Cell[134840, 3261, 460, 10, 24, "Print",ExpressionUUID->"4fa35961-f9b1-41f8-9f34-f0644d045304"],
Cell[135303, 3273, 818, 22, 43, "Print",ExpressionUUID->"f2083655-5071-4d2b-8ce6-26cc3f1ce20f"],
Cell[136124, 3297, 751, 17, 24, "Print",ExpressionUUID->"d8ce5e6c-98c6-4654-9fa3-13faad62fa20"],
Cell[136878, 3316, 434, 10, 24, "Print",ExpressionUUID->"b58cac0b-20c1-4714-ad99-73895eadaf8d"],
Cell[137315, 3328, 722, 21, 46, "Print",ExpressionUUID->"4866bf9d-b185-4110-91dd-7bf149301281"],
Cell[138040, 3351, 620, 15, 24, "Print",ExpressionUUID->"68bf6cf3-54ba-4c75-b6d7-ee49e9a734ba"],
Cell[138663, 3368, 466, 10, 24, "Print",ExpressionUUID->"5399d8d7-c222-43ed-93dd-aa061b941c1a"],
Cell[139132, 3380, 457, 13, 32, "Print",ExpressionUUID->"c68dd36a-64ea-40dd-a8b7-f26aa7376cca"],
Cell[139592, 3395, 449, 11, 25, "Print",ExpressionUUID->"986bf14c-79e5-4651-8664-2bdd11afe1bf"],
Cell[140044, 3408, 605, 17, 27, "Print",ExpressionUUID->"9f6b3b2f-2b25-48e4-9464-cad8d144a67e"],
Cell[140652, 3427, 531, 13, 24, "Print",ExpressionUUID->"5ef61900-b801-447a-b427-912195b3e7e3"],
Cell[141186, 3442, 440, 10, 24, "Print",ExpressionUUID->"a31e5cab-51ba-445b-a9b3-fd1d059b0156"],
Cell[141629, 3454, 484, 11, 25, "Print",ExpressionUUID->"abd9f158-2a60-477c-a293-398a4dbdd92a"],
Cell[142116, 3467, 442, 10, 24, "Print",ExpressionUUID->"a7cab399-e37b-47d2-89eb-f03f86ada4cd"],
Cell[142561, 3479, 778, 22, 46, "Print",ExpressionUUID->"4f8094c1-c940-4b5d-819c-5fb04c3d7f2c"],
Cell[143342, 3503, 642, 15, 24, "Print",ExpressionUUID->"e7d0bd10-0faf-4c00-8f5e-7b3ecabfb254"],
Cell[143987, 3520, 434, 10, 24, "Print",ExpressionUUID->"4ae71dab-45c9-4255-8ea4-fc43f1369302"],
Cell[144424, 3532, 619, 16, 41, "Print",ExpressionUUID->"8bd9efc7-2743-403f-8aa4-8fd0da079392"],
Cell[145046, 3550, 537, 13, 24, "Print",ExpressionUUID->"ee0f8f97-3376-4758-81b7-61c0d12e0d4a"],
Cell[145586, 3565, 455, 11, 24, "Print",ExpressionUUID->"1ade0fb1-d8ec-447b-94d7-6730e9c05a76"],
Cell[146044, 3578, 458, 13, 32, "Print",ExpressionUUID->"fcaa766f-4f09-46ef-a2f6-627188f7a7c6"],
Cell[146505, 3593, 873, 25, 27, "Print",ExpressionUUID->"d90edc24-b1fb-4c3f-86ef-409c1c321b05"],
Cell[147381, 3620, 995, 28, 27, "Print",ExpressionUUID->"8aa6cbcd-4321-4dd0-afd0-f6e9e729f345"],
Cell[148379, 3650, 801, 18, 24, "Print",ExpressionUUID->"9d6f66b8-15fd-4dda-aea0-0dc027d7fe63"],
Cell[149183, 3670, 440, 10, 24, "Print",ExpressionUUID->"15ec6364-23f4-4aa9-922b-159b0a21c865"],
Cell[149626, 3682, 912, 26, 27, "Print",ExpressionUUID->"c2ce4b5c-44e4-42bd-a8fc-eb5fe9aeed69"],
Cell[150541, 3710, 458, 10, 24, "Print",ExpressionUUID->"76ff0eb1-87ac-4f4f-b6e3-8e55e2bedb4b"],
Cell[151002, 3722, 1640, 46, 46, "Print",ExpressionUUID->"d75ef192-a6e3-4711-a127-f0199f003532"],
Cell[152645, 3770, 1101, 22, 44, "Print",ExpressionUUID->"b7a5c913-a03c-4ddc-ad89-2a8c2927ffe0"],
Cell[153749, 3794, 436, 10, 24, "Print",ExpressionUUID->"4cda74a4-3062-4209-9289-dab243ce576d"],
Cell[154188, 3806, 1514, 43, 46, "Print",ExpressionUUID->"6960d060-5242-45a6-a660-2edeaad84b48"],
Cell[155705, 3851, 1070, 21, 24, "Print",ExpressionUUID->"3d533c38-1502-4df9-9f39-cb3276368004"],
Cell[156778, 3874, 448, 10, 24, "Print",ExpressionUUID->"784a9f6a-28b9-4525-a349-95bf2c3f95c3"],
Cell[157229, 3886, 456, 13, 32, "Print",ExpressionUUID->"562ca321-553c-47a4-b445-6452fd12ab9a"],
Cell[157688, 3901, 663, 18, 27, "Print",ExpressionUUID->"60a9dbbd-7d8f-4f55-9f49-b25c752ccb2f"],
Cell[158354, 3921, 842, 22, 27, "Print",ExpressionUUID->"134ea44a-7ae6-409c-9265-d02dc8088ea1"],
Cell[159199, 3945, 748, 17, 24, "Print",ExpressionUUID->"824bee7b-9e94-48d7-86d8-bc764ac7b703"],
Cell[159950, 3964, 442, 10, 24, "Print",ExpressionUUID->"91132479-3705-4a0f-83cd-bb994e3ed6b6"],
Cell[160395, 3976, 701, 18, 27, "Print",ExpressionUUID->"3a2ed37f-2569-4349-9530-f287f59a57a9"],
Cell[161099, 3996, 456, 10, 24, "Print",ExpressionUUID->"c4e86e9e-93c4-4b47-b608-2cebaf23e010"],
Cell[161558, 4008, 1129, 32, 46, "Print",ExpressionUUID->"f1c82784-621c-434c-82b8-f691bc982b84"],
Cell[162690, 4042, 827, 18, 24, "Print",ExpressionUUID->"ce20978a-5fa9-42fe-a074-98c8a77539d8"],
Cell[163520, 4062, 436, 10, 24, "Print",ExpressionUUID->"358ec6c7-1a48-41d8-b0b3-2900e7d1bb52"],
Cell[163959, 4074, 886, 25, 46, "Print",ExpressionUUID->"3aebb265-89d4-47c0-a8bd-331b0553826e"],
Cell[164848, 4101, 704, 16, 24, "Print",ExpressionUUID->"d57f059b-d223-4acd-a403-959a641f125a"],
Cell[165555, 4119, 455, 11, 24, "Print",ExpressionUUID->"d56abed0-5698-40ed-9b98-efb211a75267"],
Cell[166013, 4132, 457, 13, 32, "Print",ExpressionUUID->"87eb3cc9-aa7a-4a8b-a726-8f0a76ff9ee1"],
Cell[166473, 4147, 882, 25, 28, "Print",ExpressionUUID->"a15670f9-28e5-4434-aad8-46bec82aa56c"],
Cell[167358, 4174, 1397, 40, 28, "Print",ExpressionUUID->"0163916e-ea06-4ce7-9f48-d1abd40b8cec"],
Cell[168758, 4216, 1247, 27, 24, "Print",ExpressionUUID->"c1d59bf6-37a5-44e0-bba0-8e1d9e5843eb"],
Cell[170008, 4245, 440, 10, 24, "Print",ExpressionUUID->"9661e836-656d-4bf5-ab08-765d7b32f1b7"],
Cell[170451, 4257, 922, 25, 28, "Print",ExpressionUUID->"426cdff8-7d04-4fbf-b2a8-bab07eaebd29"],
Cell[171376, 4284, 458, 10, 24, "Print",ExpressionUUID->"0015ecbc-6af5-4064-99e8-c58588c0cc3a"],
Cell[171837, 4296, 2232, 62, 46, "Print",ExpressionUUID->"da8a6684-105e-4d0c-a6c3-d778dbf54481"],
Cell[174072, 4360, 1426, 28, 44, "Print",ExpressionUUID->"5f663857-7802-4bee-b1da-5698e13cfa2c"],
Cell[175501, 4390, 438, 10, 24, "Print",ExpressionUUID->"a34a2179-b986-4323-a96a-26c94a5759e0"],
Cell[175942, 4402, 2611, 73, 46, "Print",ExpressionUUID->"a6a90dd7-8385-4490-9a7f-794d7b5f8f54"],
Cell[178556, 4477, 1729, 35, 44, "Print",ExpressionUUID->"ef0dae05-f8e2-4872-9d0e-25d07662a41f"],
Cell[180288, 4514, 455, 11, 24, "Print",ExpressionUUID->"58283292-c0ed-490f-8c93-e197330397bc"],
Cell[180746, 4527, 458, 13, 32, "Print",ExpressionUUID->"c681820a-ba7b-4a47-93b8-ad256d7cfccb"],
Cell[181207, 4542, 884, 25, 28, "Print",ExpressionUUID->"db92c0db-6ac0-4031-8532-e8ffdb86884e"],
Cell[182094, 4569, 1443, 42, 28, "Print",ExpressionUUID->"0f93b6c4-14cb-44d8-88ae-b7ed916f0a52"],
Cell[183540, 4613, 1251, 27, 24, "Print",ExpressionUUID->"8948e82b-d8d6-40f3-a381-fdb693d45caf"],
Cell[184794, 4642, 442, 10, 24, "Print",ExpressionUUID->"1c6a1b39-ddb2-451c-b488-0d306c1d1c24"],
Cell[185239, 4654, 921, 25, 28, "Print",ExpressionUUID->"ac4aba3e-e9ef-43f5-8cff-1ba2f6a3b609"],
Cell[186163, 4681, 442, 10, 24, "Print",ExpressionUUID->"557b6d75-9659-4eab-ac79-92f9337167c4"],
Cell[186608, 4693, 2266, 62, 46, "Print",ExpressionUUID->"312e373e-7e3c-4fb7-917a-a4b33c606687"],
Cell[188877, 4757, 1424, 29, 44, "Print",ExpressionUUID->"0a7fe40d-2c1a-4b98-8dce-d45a24bbae9d"],
Cell[190304, 4788, 438, 10, 24, "Print",ExpressionUUID->"e2a8a4f9-c0db-4d9d-b7d3-77c3bffba212"],
Cell[190745, 4800, 2640, 74, 46, "Print",ExpressionUUID->"782bfdea-ea16-426d-9245-57d1b93019cf"],
Cell[193388, 4876, 1715, 35, 44, "Print",ExpressionUUID->"5d8a433c-291d-4d8b-a753-2250ed3b7de8"],
Cell[195106, 4913, 453, 11, 24, "Print",ExpressionUUID->"6cb088df-e619-4088-aec0-90db814b8194"],
Cell[195562, 4926, 457, 13, 32, "Print",ExpressionUUID->"a4f3c828-0f65-4447-a636-fa0048795994"],
Cell[196022, 4941, 636, 17, 25, "Print",ExpressionUUID->"e2943465-9497-46d3-b40a-032bb4dfe03d"],
Cell[196661, 4960, 1338, 36, 27, "Print",ExpressionUUID->"510b0d59-1b9a-49cb-ac24-e2f81bb1c456"],
Cell[198002, 4998, 1166, 22, 24, "Print",ExpressionUUID->"759acb90-cf4a-4732-aac5-d9faaccff7bf"],
Cell[199171, 5022, 442, 10, 24, "Print",ExpressionUUID->"336bb4f4-8073-4e51-840d-372435a7460c"],
Cell[199616, 5034, 671, 17, 25, "Print",ExpressionUUID->"d8d2acf9-8143-440e-aca9-d45c1bda14a3"],
Cell[200290, 5053, 454, 10, 24, "Print",ExpressionUUID->"faa2d193-a98e-4a83-adee-c4f8895fd51c"],
Cell[200747, 5065, 996, 28, 46, "Print",ExpressionUUID->"b94db49b-cbbd-4454-936c-7e21f3729e20"],
Cell[201746, 5095, 766, 18, 24, "Print",ExpressionUUID->"445d1879-c39d-4d3f-ad0b-753bcf608872"],
Cell[202515, 5115, 436, 10, 24, "Print",ExpressionUUID->"1dfcc2e9-f4ca-460c-83bb-d6f51f56a5d3"],
Cell[202954, 5127, 1066, 29, 46, "Print",ExpressionUUID->"8518ec73-8a0b-4860-8df8-6373fc09ff69"],
Cell[204023, 5158, 849, 18, 24, "Print",ExpressionUUID->"43c09dbc-1fa2-411e-b014-04a3df6fd3ca"],
Cell[204875, 5178, 455, 11, 24, "Print",ExpressionUUID->"a2fce923-9c42-49c1-9529-aa821738d6e2"],
Cell[205333, 5191, 460, 13, 32, "Print",ExpressionUUID->"faa95ff5-4912-461e-a4f7-3887cd1a18ca"],
Cell[205796, 5206, 1460, 42, 28, "Print",ExpressionUUID->"d6d44029-86fd-4dfb-9e42-15e4bce7ac1f"],
Cell[207259, 5250, 6283, 171, 71, "Print",ExpressionUUID->"511fa281-9382-4afe-9686-536d8bb4a562"],
Cell[213545, 5423, 4121, 70, 120, "Print",ExpressionUUID->"2efe8eee-1f29-4d60-a01f-a6df9d93f186"],
Cell[217669, 5495, 440, 10, 24, "Print",ExpressionUUID->"0fd47219-cf2a-4204-9d48-2d23e946446a"],
Cell[218112, 5507, 1501, 43, 28, "Print",ExpressionUUID->"9b9d5c6f-bd55-4087-a642-c11a7baeff9e"],
Cell[219616, 5552, 458, 10, 24, "Print",ExpressionUUID->"c6207812-cbfd-415a-9ab3-60a3470aafc3"],
Cell[220077, 5564, 4834, 122, 49, "Print",ExpressionUUID->"a762b977-c691-426c-9f52-b31541e6e39b"],
Cell[224914, 5688, 2793, 48, 101, "Print",ExpressionUUID->"1c83d584-3585-48c9-b58a-7a45bfb53842"],
Cell[227710, 5738, 436, 10, 24, "Print",ExpressionUUID->"38e0a7bc-bd3c-42f4-a302-f926d5ae64ab"],
Cell[228149, 5750, 4801, 127, 69, "Print",ExpressionUUID->"fe2dc7a4-7735-42da-ba29-4b0caa971ead"],
Cell[232953, 5879, 2881, 50, 101, "Print",ExpressionUUID->"9333008d-7a96-41eb-aea5-6c5b4822ba79"],
Cell[235837, 5931, 453, 11, 24, "Print",ExpressionUUID->"42452098-ccff-4018-8d36-dadf8df51477"],
Cell[236293, 5944, 460, 13, 32, "Print",ExpressionUUID->"4550679c-44d9-44a2-9ec5-84a777d09b58"],
Cell[236756, 5959, 1742, 50, 28, "Print",ExpressionUUID->"2e5b6749-0e61-4ae3-a16f-3b01f10398fd"],
Cell[238501, 6011, 6348, 172, 71, "Print",ExpressionUUID->"97553dbd-8fa6-47f8-aeb7-d333fbe88d91"],
Cell[244852, 6185, 4092, 66, 120, "Print",ExpressionUUID->"f51cc654-7dcb-4256-8aab-44031e52f48c"],
Cell[248947, 6253, 442, 10, 24, "Print",ExpressionUUID->"89dc80a4-c57d-48b8-bfc1-4566ee5fa4bb"],
Cell[249392, 6265, 1783, 51, 28, "Print",ExpressionUUID->"fe618ae8-2307-44c3-9cce-8e95f00982a9"],
Cell[251178, 6318, 456, 10, 24, "Print",ExpressionUUID->"38e7e901-9dfd-42ed-8f69-76423cfce1a9"],
Cell[251637, 6330, 4833, 122, 49, "Print",ExpressionUUID->"3645c3d1-6fbe-4971-a6a7-35e0e5d81ed9"],
Cell[256473, 6454, 2789, 48, 101, "Print",ExpressionUUID->"5582050a-c6c2-4701-9a72-7dc1c4d4550c"],
Cell[259265, 6504, 434, 10, 24, "Print",ExpressionUUID->"1202ac61-b8dd-4709-a962-0e9aa3816d74"],
Cell[259702, 6516, 4803, 127, 69, "Print",ExpressionUUID->"2ac40bcb-d36c-4239-b35b-dc969ce83c54"],
Cell[264508, 6645, 2885, 50, 101, "Print",ExpressionUUID->"84767e14-f092-4e54-b9d0-9f0e66bb31d8"],
Cell[267396, 6697, 455, 11, 24, "Print",ExpressionUUID->"79359133-0037-4653-8c86-835bcfc0b850"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[267912, 6715, 317, 6, 58, "Chapter",ExpressionUUID->"e5b9fe57-a757-4135-a781-43383de4cc71",
 Evaluatable->False],
Cell[268232, 6723, 3658, 50, 221, "Text",ExpressionUUID->"309af718-545d-49e4-aea9-8b9303f1024a"]
}, Closed]]
}
]
*)

